# 💡 Project Description

import PictureFrame from '@site/src/components/PictureFrame';

## Bluebear Bio \- Making Cell-Free Expression Systems Accessible
<div style={{ 
    backgroundColor: "#E3EEFA", 
    color: "black", 
    padding: "20px", 
    borderRadius: "5px", 
    width: "100%", 
    boxSizing: "border-box", 
    margin: "20px 0", 
    border: "2px solid black", 
    textAlign: "center", 
    fontWeight: "bold", 
    display: "flex", 
    alignItems: "center", 
    justifyContent: "center", 
    height: "250px" /* Adjust height to control box size */ 
}}>
  The cell-free transcription and translation (TXTL) system is a pivotal technology for producing biomolecules directly from DNA templates without relying on cell viability, allowing for rapid production and testing. Cell-free expression systems have gained significant popularity in the field of synthetic biology \[1\]. Their ability to express genetic circuits in isolation from a host’s genome, to permit high-throughput experimentation, and their portability make them attractive for  use in pharmaceutical and industrial research, point-of-care applications, and the education field.

</div> 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/project-description/1-application.png"
  alt="applications"
  caption=" Applications of cell free systems"

  width="50%"
  height="50%"
/>

However, the TXTL components are prone to degradation and are reliant on cryogenic (-80°C) storage conditions. The DNA templates must equally be stored at low temperatures of \-20°C. The reagents also often take several days to prepare and require specialized equipment \[2\].

These conditions make these systems expensive in comparison to cellular expression systems, which makes it difficult for smaller labs or institutions to adopt TXTL-based technologies for research and development purposes. Additionally, the components required for the energy buffer in particular are costly, representing 50 % of the total costs alone. \[3\] This results in scale-up challenges for cell-free production and limits the use of cell-free systems to only the labs with a higher degree of funding.


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/project-description/2-lysate-challenges.png"
  alt="limitations"
  caption=" Limitations of cell free systems"

  width="50%"
  height="50%"
/>

## The Inspiration: Mighty Water Bears 

As the first iGEM team for the TUM campus Straubing for Biotechnology and Sustainability, we wanted to pick a project that would make synthetic biology more accessible and be representative of the research done at our campus, which is why we met with several professors to pitch and exchange ideas.

We met a mutual interest at the Synthetic Biology professorship, where the research is routinely carried out with cell-free expression systems. The idea began with an exciting proposal of a PhD student  from the synthetic biology professorship, Imre, who also became an important advisor for our project. What if we incorporated the impressive desiccation resistance of tardigrades to protect cell-free systems and make them more stable?


**Tardigrade Proteins**

Tardigrade-derived proteins, specifically intrinsically disordered proteins (IDPs), are integral to our project. Upon desiccation, these proteins undergo a conformational change, forming a non-crystalline, amorphous solid state through a process known as vitrification. This vitrified layer encapsulates cellular components, including proteins, nucleic acids, and organelles, which protects them against extreme desiccation conditions, and has already made them helpful in preserving different biological components, such as biopharmaceuticals \[4\].

These proteins are notable not only for their preserving properties but also for their modularity and ability to provide the same lyoprotectant function even when expressed heterologously in other organisms, like *E. coli.*

Different iGEM teams have also used some of these Tardigrade proteins to preserve other proteins and microorganisms in their projects:

- SIAT-SCIE-Team (2017) expressed tardigrade proteins to preserve probiotics in their transport.  
- QHFZ-China (2020) tried to harness these proteins to make cell-based biosensors for gout diagnoses more accessible to patients.   
- Team TU-Delft in 2017 used them to protect the protein part of their biosensor.

**Our Project**

We hypothesized that the incorporation of these lyoprotectant proteins would enhance the stability and preserve the functionality of cell-free lysate components during extended periods of storage and transportation. 

Building upon the work of Boothby et al. \[4\], we set out to use CAHS 107838 (Gene 1\) CAHS 106094 (Gene 2), and CAHS 94063 (Gene 3\) from tardigrades to stabilize lysates by coexpressing them together with a prebuilt plasmid, containing an autolysis gene (LysR) of the bacteriophage lambda, to be capable of breaking open cells through a single freeze-thaw cycle without the need for expensive and unscalable equipment like a sonicator or french press.\[6\].

Incorporation of tardigrade proteins could lower the costs of cell-free expression systems by removing the needed cold transport chains and storage. This, in turn, would allow more researchers to benefit from this technology, facilitate education on synthetic biology, and benefit more people through point-of-care (POC) applications.

We also sought to improve more areas in the cell-free system. 

Through the optimization of the energy buffer \[5\], we managed to reduce the costs of the energy solution formulation by 91.3 % of the original price while maintaining a comparable activity to the canonical energy mix.

We even tried some alternative lysate processing steps for separating the lysate from cell debris in a normal benchtop centrifuge. The previous autolysis protocol developed by Dydovik et al. \[6\] used an ultracentrifuge for high speed centrifugation, which is not available to every lab. Preparation of lysate in a standard benchtop centrifuge shows that lysate production might be more accessible than originally thought.

These results show that high-cost equipment and reagents are not required to access cell-free expression technology. 


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/project-description/3-project-descrip.png"
  alt="Bluebear"
  caption=" Our lysate: Bluebear Extract"

  width="50%"
  height="50%"
/>

**Outreach and Contact with Our community**

Our problem statement targeted a segment of society that we usually don’t communicate with, for example researchers with limited resources or high school teachers without access to well-equipped laboratory workspaces. We set out to initiate conversations with them because we knew we had a solution, but weren’t sure if we were solving a problem for our stakeholders.

We remembered one of iGEM’s objectives at the beginning of its third decade of existence: It is not only important what is done with synthetic biology, but also WHO does it.

That is why we held conversations with the researchers who inspired our work and others in the field, and tried to contact teams outside of Europe and North America to better understand the circumstances that could hinder the advancement of synthetic biology in their regions.

These conversations led to some further discoveries about our lysate, for example we showed  that it is also possible to work with simple, not chlorinated, tap water and even river water, further removing a not universally accessible resource like nuclease-free water.


**Proof of Concept**

Improving cell-free systems has already revealed innovative methods of solving problems in diagnostics, the educational sector, bioremediation, and more. Huang et al \[7\] for instance, created a synthetic biology educational kit using freeze-dried cell lysate. We built upon this idea for our **[education](https://2024.igem.wiki/tum-straubing/education)** initiatives, providing students from local schools with an insight into synthetic biology by demonstrating expression of GFP with our cell lysate. 

Additionally, we sent our own desiccated lysate, and optimized energy buffer, along with our detailed protocols, to the iGEM Wageningen Team to test. While we had tested rehydrating our cell-free systems after a few days, this was the ultimate test to discover whether they would withstand the conditions we had designed it to resist.


**Future Prospects**

In the days leading to the Jamboree and the Wiki Thaw, we would like to complete some tests to fully characterize our lysate and its components in detail.

- One of our main collaborators, Invitris, loaned us several aliquots of their cell-free expression systems we intend to stabilize with the addition of purified tardigrade proteins.  
- We also received the new Panda Pure (Ailurus) system to cleanly purify our tardigrade proteins without tags. Since our first attempts to stabilize other lysates seemed affected by impurities in the protein extracts, we are excited to test the system to properly evaluate the tardigrade protein effect without background effects.  
- We will carry out our outreach endeavors by presenting our project to the professorships at our campus and informing them about our achievements thus far.  
- We still want to send our lysate to more regions and areas worldwide\! If you are reading this far and are interested in collaborating, we would love to get in touch\!

**Project Presentation Video**

Check out our project presentation video for a deeper dive into our hard work!

<iframe title="TUM-Straubing: Bluebear Bio: Cell Free for All (2024) - Team Presentation [English]" width="560" height="315" src="https://video.igem.org/videos/embed/4f7f2577-f34a-4eca-832e-0e838d5be0cd" frameborder="0" allowfullscreen="" sandbox="allow-same-origin allow-scripts allow-popups allow-forms"></iframe>

<details>
<summary>
## References
</summary>

\[1\] J. G. Perez et al. (2016, Dec). “Cell-Free Synthetic Biology: Engineering Beyond the Cell.”, Cold Spring Harb. Perspect Biol. vol. 1, issue 8(12):a023853. Available: doi: 10.1101/cshperspect.a023853 

\[2\] D. Garenne et al. (2021, Jul). “Cell-free gene expression”, Nat. Rev. Methods Primers vol. 1, issue 49\. Available: [https://doi.org/10.1038/s43586-021-00046-x](https://doi.org/10.1038/s43586-021-00046-x)

\[3\] T. Kim et al. (2007, Jul). “An economical and highly productive cell-free protein synthesis system utilizing fructose-1,6-bisphosphate as an energy source”, jbiotec. vol. 130, issue 4, p. 389-393. Available: https://doi.org/10.1016/j.jbiotec.2007.05.002

\[4\] [T. C. Boothby *et al.* (2017, Mar). “Tardigrades Use Intrinsically Disordered Proteins to Survive Desiccation“, *Mol. Cell*, vol. 65, issue 6, p. 975-984.e5. Available: doi: 10.1016/j.molcel.2017.02.018.](https://www.zotero.org/google-docs/?kwX8Yc)

\[5\] F. Guzman-Chavez et al. (2022, Mar). "Constructing Cell-Free Expression Systems for Low-Cost Access", ACS Synth. Biol. vol. 11, issue 3, p. 1114–1128. Available: http://doi.org/10.1021/acssynbio.1c00342 

\[6\] A. Didovyk et al. (2017, Aug). “Rapid and Scalable Preparation of Bacterial Lysates for Cell-Free Gene Expression”, ACS Synth. Biol. vol. 6, issue 12\. Available: 				doi: 10.1021/acssynbio.7b00253

\[7\] A. Huang et al. (2018, Aug). Explorer: A modular synthetic biology education kit”, Sci. Adv. vol. 4, issue 8\. Available: doi:[10.1126/sciadv.aat5105](https://doi.org/10.1126/sciadv.aat5105)

</details>