# 🔁 Engineering Success
import PictureFrame from '@site/src/components/PictureFrame';

Within the framework of this project, our objective is to enhance the accessibility of TxTL cell-lysate based systems (from here onwards referred to as "cell-free systems") by augmenting their stability. For this, we employed the Design-Build-Test-Learn (DBTL) framework, iterating through  our prototypes. This allows us to make rapid adjustments based on experimental feedback. 

Each cycle was accompanied by literature review, and expert interviews to guide us towards improving our project. While adhering to the  DBTL framework, we also applied it for troubleshooting and finding alternative paths to improve our system.

<PictureFrame
  src="https://static.igem.wiki/teams/5286/engineering-success/image-1.jpg"
  alt="DBTL"
  caption=" "
  width="100%"
  height="100%"
/>

## DBTL 1: Tardigrade Proteins Protect Cell-free Lysates During Freeze-drying

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/dbtl.webp"
  alt="DBTL"
  caption=" "

  width="50%"
  height="50%"
/>

<details>
  <summary> 
  ### Iteration 1: Generating the Optimal Expression Vector
  </summary>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-3.png"
  alt="engineering success"
  caption=""

  width="50%"
  height="50%"
/>

#### **Design and Build** 
Using golden gate assembly we sought to assemble a suitable expression vector for our tardigrade genes (CAHS107838, CAHS106094, CASH 94063), allowing us to screen different options for downstream use.

After the acquisition  of the three tardigrade genes, we initially tested a set of different inducible promoters as previously reported [\[1\]](https://www.zotero.org/google-docs/?RfW1gQ). We chose pT7, pT7Max, and ptrc for this purpose. However, we also wanted to test a set of constitutive promoters for functional expression and chose six candidates from the [Anderson promoter](https://parts.igem.org/Promoters/Catalog/Anderson)  library (Figure 1).  did this because heterologous expression of the respective tardigrade genes was previously reported usingandas well as constitutive promoters.  For the assembly of all expression constructs we chose pJUMP26 (BBa\_J428350) as our backbone to ensure compatibility with the autolysis plasmid (pAD-LyseR). 


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-4.png"
  alt="engineering success"
  caption=" Figure 1: Graphical overview of generated constructs and their individual constituents."

  width="50%"
  height="50%"
/>
 
#### **Test and Learn** 
In the initial assembly of the expression constructs, we observed a notable difference in colony formation between constitutive and inducible promoters. Sequencing revealed frequent mutations  in the promoter regions of the constitutive constructs.

Furthermore, overnight cultures prepared for plasmid mini-preps showed lower yields and plasmid yields in the constitutive constructs compared to those with inducible promoters.

When testing the growth of strains with verified sequences, those containing inducible promoters exhibited much better growth kinetics. These observations strongly suggested that high levels of constitutive expression might be metabolically burdensome or  to the host cell. Following discussions with our lab advisors, we proceeded with inducible expression for the tardigrade genes.

#### **Re-Design**
Building on previous research involving the expression of tardigrade genes in *\*E. coli*\*, we shifted to using verified plasmids with inducible promoters for subsequent experiments (Figure 2\). The plasmids with inducible constructs were employed for protein purification and the pre-production of tardigrade proteins within the autolysis strain. The following Constructs were verified and used in downstream applications:   

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-5.png"
  alt="final gene casettes"
  caption=" Figure 2: Graphical representation of the final gene cassettes used for tardigrade gene expression. The first and second constructs differ only by the promoter used. Both were cloned into the pJUMP26 dropout vector and contain the RB0034 ribosome binding site, and TB006 terminator.  The first construct utilizes the T7 max promoter whereas the latter uses the ptrc promoter which includes an inverted gene cassette encoding the LacI inhibitor. For tagged expression and  a possible downstream protein purification a third construct was generated into a pet16b vector including T7 promoter , the TB0015 terminator and a his tag."

  width="50%"
  height="50%"
/>
</details>

<details>
  <summary> 
  ### Iteration 2: Stabilizing Effect of Tardigrade Protein Supplementation and Pre-expression 
  </summary>

#### **Design and Build**
Once the final expression construct was chosen and the expression of the tardigrade proteins was quantified the plasmid was to be transformed into both the autolysis strain BL21 Gold (DE3) containing pAD-LyseRand the overproduction strain (BL21 (DE3)) for subsequent protein purification. As an initial assessment we wanted to compare the lyoprotectant effects of pre-production of tardigrade genes in the autolysis strain versus the external supplementation of purified tardigrade proteins. For this we first quantified the protein concentration in the protein extract and subsequently added the required amount to reach a total concentration of 0.5 mg/ml . This concentration was chosen based on the work of the [TU-Delft 2017](https://2017.igem.org/Team:TUDelft), where tardigrade proteins were used to stabilize Gene 2 \[CASH 94063\] 

#### **Test and Learn**
While the external supplementation of tardigrade proteins derived from heat-solubility based purification demonstrated a protective effect, this effect was notably less significant compared to that of the intrinsically produced protein.
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-7.png"
  alt="final gene casettes"
  caption="Figure 3: Relative fluorescence of rehydrated samples after two weeks of room-temperature storage post-desiccation, compared to fresh lysate. Samples include G1 (CAHS107838), G2 (CAHS106094), and G3 (CAHS94063). Fluorescence data were normalized to fresh lysate, with baseline correction by subtracting the minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples."

  width="50%"
  height="50%"
/>

Proteins were stored in 50 mM HEPES and 50 mM NaCl (pH 8.0) as outlined on the protocols page. We therefore wanted to evaluate whether the concentration of NaCl influences the efficacy of the cell-free reaction.
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-9.png"
  alt="final gene casettes"
  caption=""

  width="50%"
  height="50%"
/>
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-8.png"
  alt="final gene casettes"
  caption="Figure 4: Normalized fluorescence of cell free reactions with two different final salt concentrations. Two separate salt (NaCl) concentrations were assessed, namely 6 mM and 12 mM. Fluorescence data were normalized to fresh lysate, with baseline correction by subtracting the minimum value.From each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=3 samples."

  width="50%"
  height="50%"
/>
 We found that increased salt concentrations indeed effect the kinetics and strength of cell free reaction!

#### Re-Design
The team started exploring alternative protein purification methods to enhance purity without using high salt concentrations. Our sponsor, Ailurus, provided the PandaPure protein purification kit, which uses condensate formation to purify proteins. This approach simplifies the isolation of target proteins while reducing the negative effects of salt on the reaction environment.
</details>


## DBTL 2  Optimization of the Energy Buffer Solution 
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-10.png"
  alt="DBTL2"
  caption=""

  width="50%"
  height="50%"
/>
<details>
  <summary> 
  ### Iteration 1: Setting the Stage for the First DOE Run
  </summary> 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/untitled-58.png"
  alt="DBTL2"
  caption=""

  width="50%"
  height="50%"
/>

#### **Design and Build** 
The DOE component, utilizing the I.DOT liquid handler, effectively integrated the Design-Build-Test-Learn (DBTL) cycles. This integration began with the experimental design, addressing technical challenges, then moved on to fitting the model and understanding the system's characteristics to optimize based on the results obtained. The cycle concluded with retesting to validate the design.

In the initial design phase of our DOE run for an alternative energy buffer recipe, we replaced traditional amino acids with yeast and tryptone and substituted maltodextrin(MD ) and Hexa-Meta-Phosphate (HMP)  for 3-PGA \[1\]. We faced a significant challenge in managing a small pipetting volume of 5 µL. This limitation required heavy dilution of stock solutions, as 2 µL were dedicated to the lysate, 1.2 µL for fixed energy buffer components and DNA template, leaving only 1.8 µL for other critical factors (Table 1). 

**Table 1 well composition summary** 

| Well component | Volume (µL) |
| :---- | :---- |
| Lysate | 2 |
| Fixed energy buffer components and DNA template | 1.2 |
| Energy buffer tested factors | 1.8 |

The formulation of our DOE buffer recipe also required addressing solubility constraints by preparing highly concentrated solutions due to limited dilution capacity. For example, even though 3-PGA could be solubilized at 1400 mM, practical applications required diluting it to just 71.99 mM. Additionally, MD needed to be prepared at concentrations not less than 500 mg/mL, despite testing ranges of 20 to 60 mg/mL. These measures were crucial to ensure adequate concentrations and effective interactions of components within the constrained volume available.

Based on the literature, solubility for MD can reach up to 2400 mg/mL \[2\]. For yeast and tryptone, it is crucial to prepare stock solutions of no less than 40% to effectively assess our system within the tested ranges reported in one-factor-at-a-time (OFAT) analysis .


#### **Test and Learn**
During the testing phase, we encountered solubility issues: 

Yeast could only be prepared at a 38.4% concentration, slightly below the targeted 40%,
and tryptone achieved a maximum solubility of 41.7%.  The MD solution, prepared at 500 mg/mL, was nearly completely turbid, showing precipitates and indicating that it failed to fully dissolve (Figure 5).


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-11.png"
  alt="final gene casettes"
  caption="Figure 5: Shows supersaturated MD solution of 50 mg/ml concentration.**"

  width="50%"
  height="50%"
/>

Given the practical challenges with achieving a 500 mg/mL concentration for MD, contrary to literature expectations, we adjusted our approach. We incorporated the MD into a master mix (MMX) with the lysate, DNA, and fixed energy buffer components. Simultaneously, we prepared a second MMX without MD to facilitate modulation and dilution of MD concentration per well. This strategy allowed us to use a higher total volume of 3.2 µL, effectively reducing the necessary concentration of MD (Table 2\) .

**Table 2\. Well Composition Summary of Iteration 1:** The MMX contains a DNA template (GFP)  7.8 nM, MD at 240 mg/mL, and lysate at a volume of 2 µL. The energy buffer, dispensed individually by the I.DOT, included tryptone at a concentration of 41.7% and yeast extract at the highest achievable concentration of 38.4%. 

| Well component | Volume (µL) |
| :---- | :---- |
| MMX-MD MMX+MD | 3.2 |
| Energy buffer tested factors | 1.8 |
 
In optimizing the concentrations of yeast, tryptone, HMP, and MD, we utilized a fully randomized Central Composite Design (CCD) informed by literature on One Factor at a Time (OFAT) results \[2\], \[3\], \[4\]. Each experimental run was replicated three times, with each well treated as an independent unit. However, we faced significant issues during this phase: the highly concentrated components caused clogging in the I.DOT liquid handler dispenser, and programming errors led to random, unintended dispensing into 90 well groups.

To tackle MD's low solubility, we experimented by mixing it with DNA, lysate, and fixed buffer components in the master mix (MMX), which initially mitigated solubility issues. Yet, this simpler design continued to experience dispenser clogging. Moreover, combining all components raised concerns about premature reaction initiation, potentially activating lysate for GFP production prematurely due to the nutrients in the mix. This necessitated a careful reevaluation of both our component mixing strategy and the hardware used in our experimental setup.

</details>

<details>
  <summary> 
  ### Iteration 2: The first Design of Experiment (DOE) Run 
  </summary> 
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/untitled-61.png"
  alt="final gene casettes"
  caption=""

  width="50%"
  height="50%"
/>
#### **Design & Build**
In our initial DOE run, we explored the use of tryptone and yeast as alternatives to the standard amino acids typically added to the energy buffer. We also tested maltodextrin (MD) and hexametaphosphate (HMP) as substitutes for 3-phosphoglyceric acid (3-PGA). Additionally, we tested the optimization capability for Mg-glutamate. The experimental design was carefully crafted to ensure that the ranges for these substitutes were within the operational parameters previously tested in the literature. This approach was taken to avoid the risk of negative results due to systemic failures, ensuring that all components functioned effectively within the established operational space.

### **Test & Learn**
The data obtained from the first DOE run were analyzed using a quadratic regression model, as detailed in the [Model section.](https://2024.igem.wiki/tum-straubing/model/) A contour plot was generated to visually represent the interactions and effects of the variables. The analysis revealed that lower concentrations of both yeast and tryptone resulted in better outcomes. However, deciding which of these to include in the subsequent design iteration was crucial. The decision was based on the statistical significance observed in the regression model, where yeast demonstrated a higher significance and impact on the system compared to tryptone, guiding our choice for future experiments.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/image-12.png"
  alt="final gene casettes"
  caption="Figure 5: Contour plot of standardized fluorescence as a function of tryptone and yeast extract concentrations, with maltodextrin (MD) held at 40 mg/mL and magnesium glutamate (Mg) held at 7.25 mM. The color gradient indicates the standardized fluorescence levels, with red representing lower values and blue representing higher values. The plot shows that reducing the concentrations of both tryptone and yeast extract leads to higher fluorescence, supporting the conclusion that lower concentrations of these components are beneficial for optimal performance"

  width="50%"
  height="50%"
/>

Table 4\. A summary of the first CCD design factors ranges based on the literature ranges. the design was full factorial design with 90 runs.

| Component | Minimum level | Maximum level | center point | Reference |
| ----- | ----- | ----- | ----- | ----- |
| Yeast extract (%) | 0.77 | 2.3 | 1.54 | [\[4\]] |
| Tryptone (%) | 0.83 | 2.5 | 1.67 | \[4\] |
| Mg-glutamate (mM) | 4.5 | 10 | 7.25              | \[[5\]] |
</details>

<details>
  <summary> 
  ### Iteration 3: Second CCD DOE Approach
  </summary> 
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/engineering-success/untitled-62.png"
  alt="final gene casettes"
  caption=""

  width="50%"
  height="50%"
/>
### Design & Build

In the second Iteration of our DOE approach, we refined our focus to optimize the parameters that would yield the highest standardized fluorescence. Based on insights gained from the first CCD run, tryptone was excluded, and yeast was used exclusively as the sole source of amino acids. This second Central Composite Design (CCD) aimed to thoroughly explore the optimized region identified previously. For a detailed analysis and framework of this refined approach, refer to the "Second Central Composite Design (CCD) Model" section.

### Test and Learn

**Table 5\.** Summary of Optimized Alternative Energy Buffer Formulations: This table compiles the results from both the first and second Central Composite Design (CCD) experiments. It details the formulations that led to optimized performance, highlighting the concentrations of yeast, Mg-glutamate, and maltodextrin (MD) that were found to be most effective in achieving enhanced lysate activity.

| Trypone (%) | MD (mg/ml) | Yeast (%) | Mg-glutamate (mM) | HMP (mg/ml) | Actual standardized fluorescence |
| :---- | :---- | :---- | :---- | :---- | :---- |
| 0 | 20 | 0.5 | 3 | 1 | 0.75 ± 0.01  |
| 0 | 27 | 0.5 | 3 | 1.3 | 0.6± 0.15 |

The experimental results from both designs confirmed that the optimal conditions for the process involve excluding tryptone and using very low concentrations of yeast (0.5-0.7%). Additionally, a middle range of Mg-glutamate (3-4 mM) proved ideal. Lower concentrations of maltodextrin (MD) were also characteristic of the final formulations tested, which demonstrated successfully optimized lysate activity.


</details>

<details>
  <summary> 
  ## References
  </summary>

\[1\]	Y. Wang und Y.-H. P. Zhang, „Cell-free protein synthesis energized by slowly-metabolized maltodextrin", *BMC Biotechnol.*, Bd. 9, Nr. 1, S. 58, 2009, doi: 10.1186/1472-6750-9-58.]  

\[2\]	K. F. Warfel *u. a.*, „A Low-Cost, Thermostable, Cell-Free Protein Synthesis Platform for On-Demand Production of Conjugate Vaccines", *ACS Synth. Biol.*, Bd. 12, Nr. 1, S. 95–107, Jan. 2023, doi: 10.1021/acssynbio.2c00392.]  

\[3\]	F. Guzman-Chavez *u. a.*, „Constructing Cell-Free Expression Systems for Low-Cost Access", *ACS Synth. Biol.*, Bd. 11, Nr. 3, S. 1114–1128, März 2022, doi: 10.1021/acssynbio.1c00342.]  

\[4\]	L. K. Nagappa *u. a.*, „A ubiquitous amino acid source for prokaryotic and eukaryotic cell-free transcription-translation systems", *Front. Bioeng. Biotechnol.*, Bd. 10, S. 992708, Sep. 2022, doi: 10.3389/fbioe.2022.992708.]

</details>
