---
title: 🚀 Entrepreneurship
---

## Our Mission
Our mission is to accelerate the field of synthetic biology through the development of accessible and sustainable cell-free systems. We strive to create a future where cell-free synthetic biology tools are within the reach of researchers, educators, and innovators worldwide, catalyzing groundbreaking discoveries and delivering sustainable solutions to some of the world’s most pressing challenges.
Cell-Free Systems have the potential to transform a diverse range of bioprocesses, from small-scale synthesis of protein for research purposes to mass production of medicines and industrial enzymes [1]. However, the high cost of entry, complex logistics, and specialized equipment required to utilize cell-free systems have still left many researchers in academia and early-stage biotech unable to fully leverage this powerful technology.



## The need for a strategy
While we had achieved a working prototype, we needed to fully characterize the problem for our results to be impactful and relevant.
We imagined that a good way to influence the adoption of a new technology, like cell-free expression systems, was to create an attractive product with it, which is why we set out to create an entrepreneurial strategy to do so.

## Background

Reconsult is a student initiative that focuses on providing consulting services for different ventures. They provided initial insight to help us understand the market of cell-free systems, as well as identifying trends which could further help us to develop a strategy.
Some of the key data they provided us were:
- The largest market share for cell-free technology is mainly located in North America, with 40 percent, followed by Europe with 30 percent, and finally by Asia, with 20 percent.

<PictureFrame

src="https://static.igem.wiki/teams/5286/entrepreneurship/market-share.webp"

alt="Description of the image"

caption=""

/>

-	Although the market is in its infancy and is somewhat uncertain, the size of the market is set to grow in the following years. Some of our industry advisors in the sector suggested a market size of approximately 50 million US dollars.
-	One of the market trends calls for field applications.
-	The main applications for cell-free technology in the market are for enzyme engineering and high-throughput applications, among others.

## Surveys

To better understand the market in our own context, we developed a survey to get to know our potential end users and their pain points better. We directed the survey to researchers and tried to gather data from outside the main market regions. We obtained a total of 22 responses, which were few, but still allowed us to better define our proposal.

<a target="_blank" href="https://static.igem.wiki/teams/5286/entrepreneurship/survey-results.pdf">
  <button style={{
    width: "100%", 
    backgroundColor: "rgb(238, 249, 253)", 
    color: "black", 
    padding: "10px", 
    fontSize: "18px", 
    border: "1px solid #4cb3d4", 
    textAlign: "center", 
    fontWeight: "bold", 
    textDecoration: "underline", 
    cursor: "pointer", 
    borderRadius: "10px", 
    display: "flex", 
    alignItems: "center", 
    justifyContent: "center", 
    height: "50px", 
    transition: "all 0.3s ease", /* Smooth transition */
  }}
  onMouseOver={(e) => {
    e.target.style.transform = "translateY(-5px)"; /* Moves button up */
    e.target.style.backgroundColor = "#D1E4F7"; /* Changes background color */
  }}
  onMouseOut={(e) => {
    e.target.style.transform = "translateY(0)"; /* Resets position */
    e.target.style.backgroundColor = "#E3EEFA"; /* Resets background color */
  }}
  >
    SURVEY RESULTS
  </button>
</a>



## Lean Model Canvas and Benchmarking

The obtained information was compiled into a Lean Model Canvas, and the competitors were evaluated in a benchmarking analysis.


## Lean Model Canvas

<PictureFrame

src="https://static.igem.wiki/teams/5286/entrepreneurship/paris-presentation-5min-backup-slides.webp"

alt="Description of the image"

caption=""

/>
<details><summary>
Details

**The Problem**

In Synthetic Biology, the expression of complex proteins and genetic circuits is part of everyday tasks. This, however, can be challenging, cost- and time- consuming at the prototyping stage. Cell-free expression is an alternative to circumvent these issues, but their dependency on cold chains of transportation and freezing storage requirements, as well as energy buffer costs make the technology costly and inaccessible.

**Our Solution**

We aim to tackle these barriers by reducing the costs and technical requirements to use cell-free expression systems, incorporating tardigrade proteins to protect the lysate at high temperatures, and creating a new energy buffer formulation that costs less.

**Key Metrics**

Our customers care mainly about the activity of their products, the yield, and the cost of their expression systems. We used these metrics to compare our solution against other available options in the market.

**Unique Value Proposition**

Besides providing the advantages of conventional cell-free expression systems, our kit is offered at a lower cost in comparison to similar expression systems.

**Unfair advantage**

A unique characteristic in our kit is that it can be transported without a cold chain. This decreases the cost to a measure that can't be replicated by any of the other players in the branch.

**Customer Segments**

We identified three key customer archetypes who would be greatly benefitted from our product if it were available to them in the form of a kit.

*Researchers in remote areas*

Location can greatly influence the possibility of carrying out an experiment. In the case of conventional cell-free systems, the dependency they have on freezing temperatures for storage greatly limits their applications in the field and excludes individuals who don’t have access to them.
Dr. Aurore Dupin shared us her experience of losing several cell-free expression kits (and money) due to them getting stuck at customs.

*iGEM teams*

Cell-free expression could be a novel way for iGEM teams to efficiently use their time during the competition, with rapid prototyping and efficient use of resources. It also simplifies the expression of novel complex circuits and proteins, which are commonplace in the iGEM circuit.
Several teams expressed their enthusiasm to use our prototype to express their constructs. iGEM Tec-Guadalajara further shared with us their experience, they acquired a cell extract sponsorship to use on their project, whose costs they were unable to afford.

*Biology professors/instructors*

The sterility and containment of cell-free systems enable their use in more biosafety lax settings, like a classroom. This allows easier and safer manipulation, as well as a quick and simple way to visualize transcription and translation. This would allow the teaching of synthetic biology concepts earlier and without the need of resources and equipment that conventional expression systems require.

**Channels**

Through our surveys, we figured out that researchers find out about new products and kits to use via scientific journals, presentations in conferences, recommendations from colleagues, and in some cases, iGEM itself can work as a platform to reach new customers.

**Cost Structure**

In a continuous operational expense perspective, the total cost of a kit would result in $6.56 USD. Other elements to consider are labor costs, marketing, shipping, packaging, among others.


**Revenue Streams**

In the current state of our idea, the only source of revenue identified was the income resulting from the sale of kits.

</summary>

</details>



<details>
<summary>
## References
</summary>
1. Catherine, C., Lee, K. H., Oh, S. J., & Kim, D. M. (2013). Cell-free platforms for flexible expression and screening of enzymes. Biotechnology advances, 31(6), 797-803.
2. Marshall, R., & Noireaux, V. (2019). Quantitative modeling of transcription and translation of an all-E. coli cell-free system. Scientific reports, 9(1), 11980.
3. Marshall, R., & Noireaux, V. (2019). Quantitative modeling of transcription and translation of an all-E. coli cell-free system. Scientific reports, 9(1), 11980.
</details>

import PictureFrame from '@site/src/components/PictureFrame';
