---
title: 👥 Human Practices
---
Synthetic Biology is still a relatively novel and emerging field with immense potential and a diverse range of applications from producing new-to-nature proteins for medical or agricultural purposes, to facilitating biosensor creation for environmental minoring in challenging locations, or even contributing to the creation of artificial cells with highly controllable properties, and much more. 

<div style={{ 
    backgroundColor: "#E3EEFA", 
    color: "black", 
    padding: "20px", 
    borderRadius: "5px", 
    width: "100%", 
    boxSizing: "border-box", 
    margin: "20px 0", 
    border: "2px solid black", 
    textAlign: "center", 
    fontWeight: "bold", 
    display: "flex", 
    alignItems: "center", 
    justifyContent: "center", 
    height: "250px" /* Adjust height to control box size */ 
}}>
  Within synthetic biology, cell-free systems offer unique advantages such as rapid prototyping, greater flexibility, and elimination of cellular toxicity. Cell-free systems and their vast range of applications have the potential to be revolutionary for the synthetic biology research community and the benefits from that could lead to a lot of good in the world such as reduced time and price of biopharmaceuticals research, or point of care applications for biosensors and diagnostics, especially in distant far-from-laboratory locations or even in space.
</div> 

One example of this is the company Sutro Biopharma, which successfully increased its cell-free production to a thousand liters. This example shows the possibility of cell-free lysates to be produced in large batches and used for multiple applications. Because of its scalability, cell-free systems didn’t just allow for rapid production but also greatly sped up the drug development process \[1\].

However, there are several barriers to the easy access of this incredible technology, particularly in low and middle-income countries. The main limitations are **the need for expensive reagents and specialized equipment for the distribution and storage of lysates** \[2\]. 

Knowing this, our project was focused on providing a solution that aims to eliminate these barriers, **democratizing** cell-free systems for scientists and researchers around the world. In that way, human practices is built into the very core of our project. We spoke with several stakeholders including members of the iGEM community, researchers in the field of cell-free biology from different countries, the local community here in Straubing, and private actors, to gain insights into the obstacles they have to using cell-free systems, as well as to take feedback and implement it from the people who our project would directly affect. 

Through this process, we were able to collect valuable feedback and implement it to our project. This process allowed us to greatly improve our project, and contributed to the idea of making cell-free systems easily accessible for all\!

<details>
  <summary> 
## **Defining Human Practices and Collabs:**
</summary>

By making cell-free systems accessible to all, every iGEM team becomes a potential stakeholder. For us, human practices and collaborations are not so clear-cut. We distinguish them like so:

**Human Practices:**   
We had extensive discussions with multiple iGEM teams where we’ve specifically asked about their needs as product users and existing hurdles to cell-free systems being successfully implemented in their labs. For some of these teams, we’ve also sent our lysate samples so they could try out our produced lysates in their labs. In this way, they are both: part of our process to improve our project by increasing the information collected from stakeholders, and they’re first-hand testers of our lysates. This way, we can implement feedback and collect data on how our lysate can solve the problems of the teams who managed to implement cell-free systems in their research.

The distribution kit we created to send to other teams included our desiccated lysate (named Bluebear Extract), optimized energy buffer, and a one-pager protocol of how they are re-dehydrated. A longer protocol document, designed to be sent digitally as a PDF was also created, intended for scientists completely new to cell-free systems. 

**Collaborations:**  
The other  iGEM teams we have been in contact with helped us to exchange general pieces of advice and information about synthetic biology and iGEM.They also agreed to participate in our conducted surveys, and kindly helped us to distribute the survey between interested parties.We were lucky to keep close contacts and were able to meet some teams in person and visit each other's events.

</details>

## **Cell-Free for All: Interdisciplinary Efforts**

Understanding and addressing real-world problems using synthetic biology requires the involvement of multiple stakeholders and much thought. It quickly became clear to us that bringing cell-free expression to every lab in the world would require more than simply desiccating the lysate to eliminate cold chains. 

As we enter iGEM's third decade, the focus has shifted from what we’re doing with synthetic biology, to who is driving it. Our vision of "Cell-Free for All" is grounded in the belief that synthetic biology should be a universal tool—accessible to everyone, everywhere. By making our cell-free systems scalable, affordable, and easy to use, we aim to enable a broader range of people to engage in synthetic biology.

It can involve empowering students and educators with hands-on synthetic biology tools, accelerating the development of life-saving therapeutics, or enabling on-demand production of biomolecules in remote areas. 

Below is a summary of the stakeholders we interviewed, and how they contributed to the development of our project:

### **Stakeholder Overview**
| Who | Description | Feedback | What we Implemented | Sub-Project  |
| :---- | :---- | :---- | :---- | :---- |
| **Invitris** | Munich-based cell-free startup participated in iGEM 2018\. | They confirmed that the filters we were using for sterilization were up to industry standards.  | Used suggested sterility tests; adjusted business model canvas to reflect a collaborative environment of Synbio startups | Safety, entrepreneurship |
| **Gabriele Schnippering**  | Straubing school teacher | Adjusted the lesson to be more comprehensible with a basic understanding of molecular biology. Would like her school to have an easy-to-use kit for protein expression. | Cheap, and easy to assemble cell-free education kit; interactive lessons, with hands-on activities. | Education |
| **Anibal Arce** | Co-author (Guzman-Chavez et al., 2022), a paper instrumental in our research | Gave suggestions to reduce variability, reduce cost, and improve the lysate. Gave insight into the main value proposition of our project and its impact. | Characterize the rate of transcription and translation in our system along with standardization. | Design |
| **Dr. Fernando Guzmán Chávez** | Co-author (Guzman-Chavez et al., 2022), a paper instrumental in our research | Find and reduce sources of variability, test lysate at higher temperatures, cost reduction measures. | Took on recommendation to send our lysate to teams and will find and reduce sources of variability. Will test our lysate in an incubator for hotter climates. | Design |
| **Dr. Aurore Dupin** | Cell-free researcher | We were advised to test the effect of tardigrade proteins on RNA stability, and recommended measurements. | Plan to finish purification of tardigrade protein to assess the impact on RNA stability, converted previous results from general fluorescence to amount of GFP | Design |
| **Egypt AFCM** | iGEM team | Gave us insight into their equipment, needs, and obstacles to implementing cell-free systems. Learned that they were lacking not funding but expertise. | N/A | Requirement Gathering (Human Practices) |
| **SynthAfrica** | iGEM Community Project | Gave us insight into their equipment, needs, and obstacles to implementing cell-free systems. We learned that there was both a knowledge gap and concerns about cost for implementing cell-free expression technology.  | N/A | Requirement Gathering (Human Practices) |
| **Tec De Monterrey: Guadalajara** | iGEM team | Exchanged information on iGEM experiences, Learned of their obstacles to distribution through reliance on cold chains | Our project directly addresses their obstacles to cell-free so depending on their needs, we will send them our lysate. | Requirement Gathering (Human Practices) |
| **TU Wageningen** | iGEM team | They had issues with expressing their trigger plasmid | Sent them our lysate along with an early version of our “Bluebear Extract Protocol” to test and implement | Requirement Gathering (Human Practices) |

## **Cell-Free Biosecurity Considerations**

The main regulatory frameworks that apply to Genetically Modified Organisms (GMOs)  right now are the 2009/41/EC  “Contained Use” directive and the 90/220/EEC “Deliberate Release” directive. These directives target GMOs and do not specifically target cell-free systems. Our project involved modifying and cloning cells in order to create our lysate for our cell-free system. While the contained use directive might apply to us, the EU does not have direct regulatory frameworks targeting cell-free systems. \[3\]\[4\]

For more details, on our biosecurity practices, visit our safety page:

<CustomButton title="Safety" link="https://2024.igem.wiki/tum-straubing/safety/" />


Cell-free systems tend to fall outside the purview of GMO regulations as those are focused more on living organisms. With the absence of a standard to reference, biosafety was challenging to implement. When going into schools, we wanted to be extra sure that all possible biosafety considerations were taken into account.  This is where Invitrus, as a startup using cell-free systems, was incredibly helpful in verifying that our sterilization practices were up to the industry standard. Invitrus is a key partner in determining biosafety around cell-free systems and their experience has been immensely helpful. The safety that cell-free systems bring is also suited to educational settings due to the lack of GMOs, allowing students to study them in real-time. More of that on our **[Education Page](https://2024.igem.wiki/tum-straubing/education)**[.](https://2024.igem.wiki/tum-straubing/education)


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/hp/stakeholders-graphic.png"
  alt="Description of the image"
  caption="A flowchart featuring the stakeholders we reached out to"
/>

## **Stakeholder Insights**

<details>
  <summary>
### **iGEM Community:**
  </summary>
We reached out to several teams, and iGEM institutions, to better understand their knowledge base of cell-free systems, and the problems they’re facing if utilizing them. We had these discussions,  hoping that once we better understand the needs of the industry and the synbio landscape, we could better tailor our project to those specifically needing more freedom and flexibility to use cell-free systems.

#### **iGEM Team Egypt AFCM:**   
<div style={{
display: "inline-flex"
}}>
    <img src="https://static.igem.wiki/teams/5286/hp/egypt-afcm-new-transparent-logo.png" height="200px"> </img>

    <p style={{
        marginLeft: "17px"
    }}>
    Through our discussions with Egypt AFCM, we learned that they are equipped with a \-80 C degree freezer, a centrifuge, a thermal cycle, a shaker and that they are planning to set up a new molecular biology lab. They do not, however, have the expertise or the infrastructure to support the use of cell-free systems. As they are military medical students, they mentioned that it was not equipment, or funding they were lacking, but expertise, with both students and lecturers lacking in knowledge and training. At the end of the discussion, we shared the iGEM success tips and insights we received from the Münster meetup.

    </p>
</div>



#### **Faith Omolade Adebayo from SynthAfrica:**  
We reached out to SynthAfrica, an iGEM community project team in Africa, who were kind enough to answer some questions so we could assess their knowledge of lab equipment and cell-free systems. 
<div style={{
display: "inline-flex"
}}>
    <p style={{
        marginRight: "17px"
    }}>
    We spoke with Faith Omolade Adebayo from Nigeria, the project head of SynthAfrica. SynthAfrica is an initiative that aims to bridge the knowledge gaps in Synthetic Biology in the African continent, increasing accessibility by equipping people with the tools they need to get started in the field.

    </p>
    <img src="https://static.igem.wiki/teams/5286/hp/faith-omolade.jpeg" height="250px"> </img>
</div>

They said that they had little knowledge of cell-free systems and that they would fill in our survey so we have a better understanding of why that is. Concerning lab equipment, they said that usually, labs in Africa have \-80 C degree freezers and ultracentrifuges, but not all. While their lab is quite well equipped, they said that cost would be a major point in deciding whether to use cell-free systems or not. They have never used cell-free systems before, so there is a lack of knowledge and skill in handling such systems, as well as inaccessibility due to cost reasons, they’re excited that our project directly addresses those concerns and makes this technology more accessible\!

#### **Tec De Monterrey: Guadalajara:** 
<div style={{
display: "inline-flex"
}}>
    <img src="https://static.igem.wiki/teams/5286/hp/tec-de-monterrey-logo-transparent.webp" height="100px"> </img>

    <p style={{
        marginLeft: "17px"
    }}>
    Another iGEM team we had a nice conversation with was the Tec de Monterrey, Campus Guadalajara team from Mexico. In an interview they conducted, we exchanged learning experiences from our respective iGEM journeys. They asked our team member Mara, who is a seasoned iGEMer, and Tec de Monterrey alumni, about her experiences in iGEM and synthetic biology. They were particularly interested in what people can expect heading into the field, and what could bring more people to synthetic biology research in Mexico.

    </p>
</div>  

A particularly interesting anecdote they shared, was that like us, they were also accepted for a Synthelis sponsorship. However, they never received their lysate, as shipping costs from France (Synthelis headquarters) to Mexico were too expensive for the team. This is a challenge that our project directly addresses, demonstrating the impact our lysate could have\! By eliminating cold chains, we would be able to send Tec de Monterrey our desiccated lysate and optimized energy buffer, in a small box, greatly reducing the cost to the team. That is precisely what will happen following the wiki freeze. 

#### **TU Wageningen:**  
<div style={{
display: "inline-flex"
}}>
    <p style={{
        marginRight: "17px"
    }}>
    We collaborated with the team at TU Wageningen over in the Netherlands\! They had issues with expressing their trigger plasmid so we sent them our desiccated lysate solution to help them out, while also serving to test our cell-free system. This would solve a major bottleneck in their project\! We will receive lab work updates from them following the wiki freeze.

    </p>
    <img src="https://static.igem.wiki/teams/5286/hp/tu-wageningen.webp" height="300px"> </img>
</div> 

TU Wageningen received our **Bluebear Extract Protocol** whilst it was still in its development phase, and we received valuable feedback on it, allowing us to tailor it further as per the field’s requirements.
 
 </details>

<details>
  <summary>
### **Researchers in the Field of Cell-free Biology:**
 </summary>

#### **Dr. Aurore Dupin:** 
We also reached out directly to researchers in the field of cell-free systems. One such researcher, who was gracious enough to speak with us, was Dr. Aurore Dupin. A postdoctoral candidate at the Weizmann Institute of Science in the field of synthetic biology, including cell-free systems.
<div style={{
display: "inline-flex"
}}>
    <p style={{
        marginRight: "17px"
    }}>
    She gave us several suggestions to improve our project. Firstly, she identified potential struggles we could run into when shipping our lysate to teams across the world. She mentioned, based on her own and collaborators’ struggles when shipping and receiving lysate on dry ice, that packages are sometimes delayed, and the contents spoil.

    </p>
    <img src="https://static.igem.wiki/teams/5286/hp/aurore-dupin.png" height="200px"> </img>
</div>

Through this discussion, we recognized the need to extend our testing beyond just a few days after desiccation to gain a comprehensive picture of its robustness. Consequently, we set aside samples of lysate to undergo additional testing in the weeks leading up to Paris. This will allow us to gather crucial data on its performance over time, helping to validate our solution and refine our approach based on real-world conditions.

She also recommended that for more comparable measurements, we should implement a standard fluorescence dependency curve that could be made by measuring fluorescence from known specific amounts of purified GFP protein. This would help to translate observed fluorescence measurements to the actual amount of synthesized proteins. We took on that advice, and quantified the GFP expression by converting the previous results from general fluorescence-based measurements to the amount of synthesized protein.

In addition, after the wiki freeze, once we finish the purification of tardigrade proteins, we will assess their effect on RNA stability. Aurore suggested that once we have purified proteins, we should not only track the rates of translation but also look at the rates of transcription. She kindly suggested some variants of aptamers to check RNA stability and transcription rates which we plan to do\!

#### **Dr. Fernando Guzmán Chávez**
<div style={{
display: "inline-flex"
}}>
    <img src="https://static.igem.wiki/teams/5286/hp/fernandoguzmanchavez.jpg" height="200px"> </img>

    <p style={{
        marginLeft: "17px"
    }}>
   Dr. Guzmán’s 2022 paper “Constructing Cell-Free Expression Systems for Low-Cost Access” was instrumental to our project. We attempted to replicate the results in this paper but were not fully able to, so we had the incredible opportunity to ask the author what could be the issue about that\! 

    </p>
</div>  

He informed us that the most probable reason why the results weren’t fully replicated, was due to sources of variability. He suggested we find those sources of variability, and work towards reducing them, as creating standard and replicable results are vital in synthetic biology. He suggested that we stay in very close contact with the teams we’re sending lysate to, so we can check for variations that arise, allowing us to eventually work towards a standard product, with replicable results. This advice not only helped our project but also sparked the awareness of variability problems between different lysate preparation techniques or even different batches of lysates in general. To follow up this issue, we are eager to find a solution to reduce the variability and make lysate production more reliable.

Dr. Guzmán also suggested that we try testing our lysate by exposing it to hotter temperatures, to simulate shipping our lysate to countries with hotter climates. For this reason, we have decided to run tests with our lysate in an incubator and bring the results to Paris. Additionally, he suggested cost-reduction measures based on research about using cheese by-products to replace IPTG, a fairly costly compound. His final suggestion was that we optimize the moment the culture is taken before producing the lysate, as the stage in the growth curve the bacteria are in, will determine the state of transcription and translation components.

Dr. Guzmán showed great enthusiasm for the project, as it is an idea that he thought of years ago, but was never able to carry out. This enthusiasm was fueled by his belief that making cell-free technology more accessible to teachers in Mexico would enable more students to learn about synthetic biology. An area they could perhaps take inspiration from is our educations page\!


<CustomButton title="Education" link="https://2024.igem.wiki/tum-straubing/education/" />
<br> </br>


#### **Dr. Annibal Arce:**
<div style={{
display: "inline-flex"
}}>
    <p style={{
        marginRight: "17px"
    }}>
    We were also incredibly lucky to interview Dr. Annibal Arce, a co-author on the paper “Constructing Cell-Free Expression Systems for Low-Cost Access” by Guzman Chavez et al. (2022). Dr. Arce gave us a lot of great advice on several aspects of the project:

    </p>
    <img src="https://static.igem.wiki/teams/5286/hp/anibal-arce.jpg" height="200px"> </img>
</div>

**To Reduce Cost and Variability:**
He suggested that we perform dialysis of the lysate to remove any viscous leftovers that can affect the reaction while emphasizing the importance of mixing. He also suggested that we do a run-off experiment and run samples in a small tube using heat and shaking due to the need for oxygen. He also mentioned that the shape of the wells in plate experiments is important because the surface tension can influence variability. Finally, he cautioned us that standard results are required for biosensors, which are harder but not impossible while also suggesting that Midiprep is the minimum of DNA preparations we should use.

To reduce cost, he suggested that a tRNA preparation can be home-brewed which can help us reduce cost.

**To Generally Improve the Lysate**

For general improvements to our lysate, he suggested that instead of using maltodextrin and HMP, we should use PEP, sucrose, and lactose, as they would be much faster. He strongly suggested that we check any compounds for if they’re using glycerol because it can inhibit the reaction. Finally, he mentioned that PPPase (pyrophosphateas) can help with magnesium sequestration. We were advised to measure degradation rates using the broccoli expression curve. Due to the time limits of our project we were not able to implement all the suggestions yet, but we are looking forward to doing so in the near future and testing new variants of even more improved lysates.

**Future Perspectives**

For future considerations within and beyond the lab, Dr. Arce gave us some very insightful advice. He asked us to reflect on how we evaluate the quantity of the protein with questions such as: “Is the GFP expressed/assembled properly?”. He asked us to look into Pentathonate and how it can be a common factor amongst very different metabolic routes. On the topic of why the reaction stops, he mentioned that it's not really because resources are depleted. After all, RNAses are hard and already present in the lysate. Rather, he mentioned that it's possible that lysate reactions only last one hour, and the rest of the curve is the maturation of the protein.

To tackle current and future problems, Dr. Arce suggested that we should implement quality controls as there are many elements in the lysate that should be evaluated that are separate from the variability. Additionally, he advised us to focus on characterizing the tardigrade protein and evaluating the transcription rate with broccoli aptamers along with translation.

**Opinions About Our Project:**

Dr. Arce said that a tardigrade protein and pantothenate are really good ideas to drive costs down, however, to be able to actually prove that our system makes sense, we need to properly characterize it. He emphasized that with our motto of ‘Cell Free for All’, we’re providing value by positioning ourselves as a new, cost-effective, available option. Whilst our lysate may not be the best strain, capable of resisting everything, we are a new attractive option tackling important cell-free system accessibility issues. 

</details>

<details>
  <summary>
### **Local Community:**
</summary>

#### **Insights from Local Teachers:**

<div style={{
display: "inline-flex"
}}>
    <img src="https://static.igem.wiki/teams/5286/hp/school-photo-2.jpg" height="200px"> </img>

    <p style={{
        marginLeft: "17px"
    }}>
   As part of our efforts to promote awareness and accessibility of synthetic biology, we engaged with local community stakeholders in education. 

    </p>
</div> 
 
We visited several schools with the following key objectives: assess the existing knowledge of synthetic biology and cell-free systems among teachers and students, gather feedback and suggestions to improve the accessibility of these technologies in educational environments, and co-develop a high school lesson plan that incorporates their insights and addresses identified challenges. Through this initiative, we aimed to not only educate but also actively involve educators and students in shaping the future of synthetic biology in the classroom.

In total, we interviewed four teachers across Straubing and Regensburg (both cities located in Bavaria region, in Germany). With their continuous input, we created a lesson plan to introduce synthetic biology, and our project, to the students. We came prepared with a cell-free reaction educational kit, featuring our own 3D printed fluorescence microscope. We also brought Tardigrades to the lesson, which the students could ‘hunt’ for in groups, using microscopes provided by the schools, and would get more familiar with the most important organism in our project. 

One key piece of feedback we received was the importance of using visual aids, as well as interactive tools such as Menti meters, and quizzes to assess student understanding. When we discussed the idea of developing more affordable and accessible cell-free system kits for educational use, the teachers expressed strong support. They highlighted the value of students being able to directly observe and engage with scientific concepts, noting that GFP experiments would be particularly effective for this. Although the schools we visited had limited prior knowledge of cell-free systems, we were encouraged by their enthusiasm. In response to this feedback, we worked to make our lesson plan as engaging and interactive as possible, integrating their suggestions to improve the educational experience.

Head to our Education page, for more details on our [Education Initiatives](https://2024.igem.wiki/tum-straubing/education/)!

</details>

<details>
  <summary>
### **Private Actors:**
</summary>

#### **A Cell-free Collab with Invitris:**
<div style={{
display: "inline-flex"
}}>
    <p style={{
        marginRight: "17px"
    }}>
    As a Munich-based cell-free startup that participated in iGEM 2018, Invitris was the perfect company for us to seek guidance from. They were kind enough to offer us not only tangible advice for our project, but also their own samples of lysate for us to test and experiment with\!

    </p>
    <img src="https://static.igem.wiki/teams/5286/hp/invitrus-meetup.jpg" height="200px"> </img>
</div>

**Wet Lab Wisdom:**

A recurring question that we considered was how less equipped labs (i.e. those with no plate reader) can measure the success of our lysate. Mara, a member of our team recounted that her Alma mater university Tec de Chihuahua in Mexico, wasn’t equipped with a plate reader, so this was an important consideration. Invitris advised, that in their experience, most labs have an absorbent spectrophotometer. Those labs should be able to express the desired protein and then look for the change of the peak of around 400-500 nanometers.

Another important insight we received from Invitris was that distributing our lysate as a paper-based biosensor could further enhance accessibility. Although restrictive in practicality, we were informed that filter paper is the industry standard for biosensors, and that those without a plate-reader should also have some type of device such as a gel-documentation instrument to visualize fluorescence results. Taking on this feedback, we constructed several paper-based biosensors, using our desiccated lysate, and rehydrated them, yielding great fluorescence results. This suggestion from Invitris helped us make this very important improvement, to enhance the accessibility of our lysate\!

**Entrepreneurship:**

We also received great feedback on the [entrepreneurship](https://2024.igem.wiki/tum-straubing/entrepreneurship) side of the project. We learned from Invitris, that in their experience, the synthetic biology community is a very tight-knit one, particularly in the cell-free corner. We asked about their competitors, and what the industry is like in terms of different competitors. We got a rather unexpected response, being that traditional competition as it exists in other industries has not really been what they’ve seen. They mentioned that competition and collaboration operate hand-in-hand, and that their own business model is very service-heavy, with consultations, and exchanges of intellectual property commonplace. Their initial customers were academic groups and connections via iGEM, and they gave us some examples of the kind of services they provided when first getting started.

They mentioned that the business model they have seen most of is called “co-development”, where they collaborate with other companies to develop a product. After developing the product, Invitris received royalties from the profits generated from the product. Collaborators usually paid to use Invitris’ IP. They mentioned that the new IP can be exclusive but is mostly shared depending on the contract. This gave us a really good insight into possible entrepreneurial pathways for our project.

</details>

### Our Survey Understanding the Needs of the Synbio Community 

We conducted an entrepreneurship survey to understand better the needs of our potential customers, collaborators, and stakeholders. Although we only have 21 responses, we can still draw some insights by looking at the data we have in a more qualitative light.
The survey consisted of questions about the contact to, application of, and opinion on expression systems, especially running on cell lysate. We got responses from laboratories around the world and learned some very interesting details about them. A quick overview indicates that while most participating laboratories have the equipment to work with cell-free systems when it comes to storage, production, and mixing the energy solution, access to a freeze dryer is a real bottleneck. 

As per our survey, the most common issues in producing proteins are low yield of the products, aggregation of either the products or the substrates, and degradation of the molecules as well as the toxicity of needed or produced substances which limits the expression rate. Toxicity especially was found to be an occasionally appearing problem.

The pain points of the expression workflow, time consumption, and the possibility of upscaling were mentioned. Reproducibility and expenses had a slightly lower negative impact. This is partly reflected in the answers to the question about the most important factors that expression tools should have. Thereafter, most surveyed lab employees wrote that Performance and cost are very crucial, whilst Technical support and vendor reputation are neglectable.

At the moment the preferred way to deal with the issues named above is optimization of the used culture. This can be a differently mixed media or modified inducer concentration. 
The most valuable feature a product, designed to help express toxic or challenging substances, should have is an optimized cost-yield efficiency. This is followed by less toxicity and good scalability. Our project also removes the need for a freeze dryer, which is the equipment that the least amount of labs seem to have in our survey.

The data shows that most labs work with bacteria and yeast cells. This means, switching to our improved lysate-based cell-free expression systems (CFES) would have a big impact. According to Perez et al., 2016, even a change to normal CFES could lead to savings in money and time. [3]


<details>
<summary>
## References
</summary>
[1]    A. Tinafar, K. Jaenes, and K. Pardee, “Synthetic Biology Goes Cell-Free,” BMC Biology, vol. 17, no. 1, Aug. 2019, doi: https://doi.org/10.1186/s12915-019-0685-x.

[2]	  Guzman-Chavez, F., Arce, A., Adhikari, A., Vadhin, S., Pedroza-Garcia, J. A., Gandini, C., ... & Haseloff, J. (2022). Constructing cell-free expression systems for low-cost access. ACS Synthetic Biology, 11(3), 1114-1128.

[3] 	J. G. Perez, J. C. Stark, and M. C. Jewett, “Cell-Free Synthetic Biology: Engineering Beyond the Cell,” Cold Spring Harbor Perspectives in Biology, vol. 8, no. 12, p. a023853, Oct. 2016, doi: https://doi.org/10.1101/cshperspect.a023853.

[4]    L. S. Sundaram, J. W. Ajioka, and J. C. Molloy, ‘Synthetic biology regulation in Europe: containment, release and beyond’, Synth. Biol., vol. 8, no. 1, p. ysad009, Jan. 2023, doi: 10.1093/synbio/ysad009.

[5]    T. Sheahan and H.-J. Wieden, ‘Emerging regulatory challenges of next-generation synthetic biology’, Biochem. Cell Biol., vol. 99, no. 6, pp. 766–771, Dec. 2021, doi: 10.1139/bcb-2021-0340.

</details>

import PictureFrame from '@site/src/components/PictureFrame';
import CustomButton from '@site/src/components/CustomButton';
