# 🧪 Results

import PictureFrame from '@site/src/components/PictureFrame';

Cell-free systems are powerful tools for synthetic biology, enabling rapid protein production without the limitations of living cells, and are used in applications like biosensors, vaccine production, and gene circuit studies. However, they face challenges such as expensive energy buffers, the need for cryogenic storage, and reliance on costly equipment, making them less accessible to smaller labs or institutions in regions with limited resources. To address these issues, the team drew inspiration from tardigrades, incorporating their  intrinsically disordered proteins in order to stabilize and protect cell-free systems, reducing the need for high-cost equipment and special conditions. Their solution makes cell-free systems more accessible, requiring less equipment and making them viable for use in underfunded labs and educational settings worldwide.

Cytoplasmic Abundant Heat Soluble (CAHS) proteins in tardigrades are key players in protecting cellular environments under extreme conditions like desiccation. These intrinsically disordered proteins (IDPs) mitigate damage by stabilizing cellular structures and preventing denaturation during stress events. Boothby et al. demonstrated that CAHS proteins are highly expressed in response to desiccation and provide protection by forming protective glass-like structures around cellular components during dehydration \[1\]. Other studies have shown that CAHS proteins, when expressed in bacteria, preserve cellular function during lyophilization, indicating their potential for stabilizing biological materials in storage environments \[2\]. These proteins not only preserve cellular components in tardigrades but are also being explored for biotechnological applications in protecting human cells from stress \[3\]. Two previous iGEM projects involved the utilization of the lyoprotectant capabilities of tardigrade proteins, namely TU-Delft 2017 and QHFZ-China 2017, where  they showed that heterologous expression of the tardigrade proteins improves the desiccation survival rate of expressing strains. Furthermore, TU-Delft showed that the proteins also serve to stabilize enzymes in solution, further reinforcing their protective capabilities outside of their natural system. 

## **Stabilizing Cell-Free systems using Intrinsically Disordered Proteins from Tardigrades**

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-1.png"
  alt="graphical summary of the initial project phase"
  caption="Figure 1: Overview of the initial project phase. The selected expression vector was transformed into a BL21(DE3) expression strain and a second strain carrying an autolysis plasmid. The goal was to evaluate the production of lyoprotectant proteins either internally within the lysate-producing strain or externally after purification, enabling stabilization of other extracts. Concurrently, efforts focused on developing a desiccated energy buffer to facilitate transport of all components for cell-free reactions.
  "
  width="50%"
  height="50%"
/>
   


As a first  part of this project, we aimed to stabilize *E. coli* cell-free systems using tardigrade proteins. For convenience and improved accessibility, we sought to produce the tardigrade proteins *in situ*, in the strain that is harboring the autolysate plasmid  \[4\]. As outlined above, previous work had shown that several lyoprotectant heat-soluble proteins from tardigrades protect proteins and living cells during desiccation. To our knowledge, it has not been attempted to protect cell-free expression systems with tardigrade proteins during desiccation or freeze drying, which we aimed to test in our project. Based on previous work by Boothby et al. (2017), where living  *E. coli* cells were stabilized and showed increased desiccation survival we reasoned that the same genes may help to improve the stability of cell-free systems.  the following tardigrade genes, originally stemming form *H. dujardini* \[1\] :


*CAHS 107838  (termed ‘Gene 1’)* 

CAHS 106094  *(termed ‘Gene 2’) \[[BBa_K2306005](https://parts.igem.org/Part:BBa_K2306005)\]*

CAHS 94063   *(termed ‘Gene 3’)* 

In our study, these genes will subsequently be referred to as Gene 1, 2 and 3 respectively. Out of these genes, only “Gene 2” has been described by previous iGEM teams for the protection of living *E. coli* cells and notably for the protection of enzymes such as Cas13a and ß-Galactosidase by TU-Delft .

Our first step was to test which construct would be best for the expression of the tardigrade proteins within the cell-free system. As both the Marburg collection (available  in our host-lab), as well as the iGEM distribution kit, are assembled by using the Golden Gate cloning method, we wanted to employ this method for the assembly of our constructs as well.

### **Expression of Tardigrade Genes in *E. coli***

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-2.png"
  alt="graphical summary of gene cassette"
  caption="Figure 2: Graphical representation of the final gene cassette used for tardigrade protein expression. The three tardigrade genes (Gene 1-3) were cloned into the pJUMP26 dropout vector and contain the RB0034 ribosome binding site, and TB006 terminator. After an initial screening, the T7 max promoter was chosen as an initial expression cassette.
  "
  width="50%"
  height="50%"
/>
  

Following the method of Boothby et al.,(2017) the heat solubility characteristics of the tardigrade proteins were used to purify the proteins.  


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-3.png"
  alt="SDS Page"
  caption="Figure 3: SDS page of heat soluble CAHS proteins expressed in BL21 (DE3). For each Gene two cultures were grown and assessed simultaneously. Purification was performed using the protocol previously described by Boothby et al \[1\]. The page ruler is annotated on the left and the bands corresponding to the different tardigrade genes 1: 27.14 kDA 2: 27.347 kDA and 3: 26 kDa are annotated respectively. sfGFP and negative control induced BL21(DE3) strain are presented as positive and negative controls.
  "
  width="50%"
  height="50%"
/>
  


Following purification we first quantified the protein concentration in the protein extracts and subsequently added the required amount to reach a total concentration of 0.5 mg/ml (figure 3; 4 a, b)  . This concentration was chosen based on the work of the TU-DELFT team in 2017, where this concentration and onwards was found to exhibit lyoprotectant effects on ß-galactosidase enzymes in solution.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-4.png"
  alt="graphical summary of the initial project phase"
  caption=" Figure 4: A. Standard curve used for the quantification of protein concentrations in protein extracts generated using the heat soluble protein purification protocol from Boothby et al. (2017) B. Determined protein concentrations in protein extracts using the same protocol. Gene 1, 2 and 3 are marked respectively. The bar charts and whiskers represent mean and standard deviations calculated n=3 samples.
  "
  width="50%"
  height="50%"
/>
  

To assess the capability of our tardigrade proteins to protect cell-free systems against the effects of desiccation we lyophilised lysate samples, where we had either expressed tardigrade genes *in situ* or where we added the proteins externally.  The samples were stored at room temperature for a time-frame of 2 weeks and rehydrated in the same volume that it was desiccated at.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-5.png"
  alt="room temp storage"
  caption=" Figure 5: Relative fluorescence of rehydrated samples after two weeks of room-temperature storage post-desiccation, compared to fresh lysate. Samples include Gene 1 (CAHS107838), Gene 2 (CAHS 106094), and Gene 3 (CAHS 94063). Samples where the tardigrade proteins were supplemented externally are indicated with “s.”. Fluorescence data were normalized to fresh lysate, with baseline correction by subtracting the minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples.
  "
  width="50%"
  height="50%"
/>
  


As outlined in the [Engineering Page](https://2024.igem.wiki/tum-straubing/engineering),  we observed that while Gene 1 and Gene 2 demonstrated protective capabilities when produced internally, the externally supplemented proteins exhibited diminished protection(Figure 5). The storage buffer contains 50 mM NaCl - (more details in our [Protocols](https://static.igem.wiki/teams/5286/protocols.pdf)), so we hypothesized that there could be an inhibitory effect of the protein storage buffer on the lysate performance.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-6.png"
  alt="flourescence"
  caption=" Figure 6: Normalized fluorescence of cell-free reactions with two different final salt concentrations. Two separate salt concentrations were assessed, namely 6 mM and 12 mM respectively. Fluorescence data were normalized to fresh lysate, with baseline correction by subtracting the minimum value.From each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=3 samples.
  "
  width="50%"
  height="50%"
/>
  


We found that an increased salt concentration does indeed inhibit the cell-free reaction. To counteract this we already started an additional protein purification protocol using the Panda-Pure protein purification kit supplied by our sponsor. 

As further validation we repeated the last experiment with biological replicates and technical replicates  to obtain a more robust  dataset. Based on the previous desiccation experiment we only observed the intrinsic expression of gene 1 and 2 rather than gene 3 . 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image7-2.png"
  alt="fluorescence of rehydrated samples"
  caption=" Figure 7: Relative fluorescence of rehydrated samples after two weeks of room-temperature storage post- lyophilisation, compared to fresh lysate. Samples include Gene1 (CAHS107838), Gene 2 (CAHS 106094). Fluorescence data were normalized to fresh lysate, with baseline correction by subtracting the minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=3 samples.
  "
  width="50%"
  height="50%"
/>
  

Surprisingly, Gene 2 performed much better than in the previous assessment indicating variability between batches and the handling during the desiccation process.  
In parallel, the same rehydrated lysate was used to start a reaction in PCR tubes for visualization using the Chemidoc System after 3 hours of incubation at room temperature.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-8.png"
  alt="rehydrated samples"
  caption=" Figure 8: Composite Chemidoc visualization of cell-free reactions from rehydrated samples after 2 weeks of room-temperature storage, following 3 hours of incubation. The PCR tubes were imaged using Alex 480 (blue), Dylight 550 (green), and Cy5 (red) channels. Each sample was run in biological duplicates, with lysates expressing Gene 1 labeled as G1 and G2, respectively.  The untreated lysate is lysate from the canonical autolysate strain (BL21 (DE3) pAD LyseR).
  "
  width="50%"
  height="50%"
/>
  


Despite variance between experiments, gene 1 (CAHS107838) conferred the strongest desiccation tolerance (Figure 4 and 5). 

Building on these findings, we aimed to evaluate whether cell-free components could be successfully desiccated using a low-cost vacuum desiccation setup. Given its superior performance in previous lyophilization studies, we specifically examined the desiccation protection of *Gene 1* after two weeks of  room-temperature storage following vacuum desiccation.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-9.png"
  alt="activity lysate"
  caption=" Figure 9: Activity of vacuum desiccated Lysate  after 2 weeks of storage at room temperature. The vacuum desiccated lysate from Gene 1.
  "
  width="50%"
  height="50%"
/>
  

Given that Lysate can be desiccated with low-cost vacuum desiccation we next sought to assess whether or not  the energy buffer can be stabilized using different lyoprotectants as well. For this we took inspiration from Guzman Chavez’s work where different concentrations of sugars were investigated for their lyoprotectant properties \[5\]. In this work they found an optimal concentration of 11.2 mM  for Maltodextrin and Lactose respectively which both exhibited desiccation protection effects as well as function as a potential additional energy source for the cell-free system . For Trehalose the same concentration we described previously was used, namely 0.54 M based on work from reference \[6\]. After low-cost vacuum desiccation the samples were left at room temperature for 1 week prior and resuspended in nuclease free water. 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-10.png"
  alt="activity"
  caption=" Figure 10: Assessment of cell-free reaction activity of  energy buffer desiccated with different lyoprotectant sugars. Lac: Lactose MDX: Maltodextrin Tre: Trehalose pos: positive control (fresh energy buffer mix). Error bars represent the standard deviation for n=3 samples.
  "
  width="50%"
  height="50%"
/>
 

In alignment with past findings we found lactose and Maltodextrin  to exhibit strong desiccation protection abilities and the activity even surpassed the fresh energy buffer (Figure 10 ). This enhanced activity may be attributed to its ability to stabilize cellular components while simultaneously providing metabolic support, surpassing the protective effects observed in the fresh energy buffer.

### **Dessication of Cell-Free Reactions in Paper-Based Systems**

After a conversation with Kilian Vogele from Invitris, a start-up company and one of our main stakeholders, the idea was brought up to co-dessicate the energy buffer and lysate on paper and simply re-hydrate the paper using a mix of water and template. This format could be utilized for point of care applications such as biosensor systems . Instead of freeze drying the samples, they were desiccated using a conventional low-cost vacuum dessicator (Figure 11a ).

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-11.png"
  alt="desiccation"
  caption="Figure 11: a. Low-cost vacuum desiccation set up used in this study for the dessicaton of cell-free reactions and paper based systems. b. Composite Chemidoc visualization of cell-free reactions from rehydrated paper systems after 2 weeks of room-temperature storage, following 3 hours of incubation. The PCR tubes were imaged using Alex 480, Dylight 550, and Cy5 channels.
  "
  width="50%"
  height="50%"
/>
  


##           **Optimizing the Energy Solution for Low-cost Access** 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-12.png"
  alt="graphical summary of the second project phase"
  caption="  Figure 12: A schematic overview of the second phase of the project, focused on optimizing the energy buffer for cost-effective accessibility. After evaluating the functionality of new, more affordable components through individual replacements and testing, we proceeded to assess their combinatorial effects.
  "

  width="50%"
  height="50%"
/>
  

One major hurdle standing in the way of accessible cell-free systems is the costly energy buffer constituting roughly 50 % of the total reaction costs \[7\]. Therefore one aim of our project is to identify an alternative energy buffer mix that significantly reduces the costs of cell-free systems contributing to their accessibility. We initially conducted a cost analysis based on the canonical energy buffer mix published in Sun et al. (2013) reseach paper which represents a standard state-of-the-art formulation \[8\]. For this, we looked at current prices for each component and calculated the price per millimole as well as the cost per milliliter reaction volume based on the quantity that has to be added to the energy mix (see [Protocols](https://static.igem.wiki/teams/5286/protocols.pdf) and Fig. 13).

In this analysis, we identified the most cost-prohibitive components which we sought to substitute.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-13.png"
  alt="energy buffer components"
  caption=" Figure 13: The top 10 most costly components of the energy buffer used in standard cell-free reactions. Due to the limited time frame of our project, we choose to replace the top-three cost-prohibitive components, namely 3-PGA, Amino Acids, CoA, as well as to replace nucleotide triphosphates (NTPs) with alternative components.
  "
  width="50%"
  height="50%"
/>
  

### Replacement of the Nucleotide Source

As it was described by Jewett et al. 2008, the substitution of nucleotide triphosphates (NTPs) with Nucleotide monophosphates (NMPs) could be a simple means through which costs can be cut \[9\]. Indeed, our cost analysis revealed that the usage of NMPs is roughly 24.6 % cheaper. This would serve to reduce the total cost of the energy buffer by a factor of 1.3 % \[9\] (Figure 14).

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-14.png"
  alt="price graph"
  caption=" Figure 14: Price Reduction achievable by the replacement of NTPs with NMPs.
  "

  width="50%"
  height="50%"
/>

  

To assess the effect of the substitution of nucleotides, we kept all other components of the canonical energy buffer \[8\]. The measurement was conducted in technical duplicates with Lysate generated from the bacterial autolysate strain and a sfGFP reporter constructed under the control of a strong, constitutive bacteriophage lambda promoter (P70) \[BBa\_K2411000\].
 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-15.png"
  alt="NTP graph"
  caption="Figure 15: Replacement of NTPs in standard energy buffer (SB) with NMPs. Baseline correction was performed by subtracting the minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples.
  "

  width="50%"
  height="50%"
/>
  

Results from this experiment showed no severe effect of substitution of NTPs on the overall cell-free reaction activity (Figure 15). As the energy balances and fluxes will change with each substitution, the effects of NTP substitution were studied again for each alternative energy constituent.

### Replacement of Amino Acids with Complex Sources

The second highest cost contributor to the Energy solution that we identified was the amino acid mix which also represents one of the most labor-intensive parts of the workflow as the individual amino acids need to be completely dissolved in water and pH adjusted. 

In an interesting case study, Nagappa et al. (2022) identified tryptone and yeast extract as a potential cost-effective alternative that could be used \[10\]. Our aim was to verify their findings with our system and also to assess different concentration ranges as well as the effect of the supplier which was not considered in their original study. According to our calculations, substituting the amino acid solution with yeast extract could decrease the total energy buffer costs by 22.2 %.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-16.png"
  alt="graph"
  caption=" Figure 16: Price Reduction achievable by the replacement of Amino Acids with complex amino acid sources.
  "

  width="50%"
  height="50%"
/>
  

#### **Replacing Amino Acids with Tryptone**

In alignment with the study by Nagappa et al. (2022) we first sought to test whether or not tryptone could be utilized as a substitute for the defined amino acid mix \[10\]. In the previous study, the authors identified an optimal tryptone concentration of 1.5 % (w/v). Therefore we chose this concentration as a starting point for our initial testing.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-17a.png"
  alt="graph"
  caption=""

  width="50%"
  height="50%"
/>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-17b.png"
  alt="graphical summary of the initial project phase"
  caption="Figure 17: Replacement of Amino Acids in standard energy buffer EB (original) with Tryptone. Baseline correction was performed by subtracting the minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples. Top: Timeseries vizualisation of flourescence, standard deviation is depicted as an error band (n=2). Bottom: Mean value of the last timepoint 9.96hours.
   "

  width="50%"
  height="50%"
/>
  

 In our experiment, tryptone performed comparably to the canonical energy buffer containing amino acids (see Fig. 17). Consequently, this component was integrated into our workflow for subsequent optimization. 

#### **Replacing Amino Acids with Yeast Extract**

Another complex amino acid source examined in this project was the substitution of amino acids with yeast extract. Similarly to tryptone, we chose the concentration previously identified as optimal by Nagappa et al.\[10\], namely 0.8 % (w/v).

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-18a.png"
  alt="Reaplacement amino acids"
  caption=" "

  width="50%"
  height="50%"
/>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-18b.png"
  alt="Reaplacement amino acids"
  caption="Figure 18: Replacement of Amino Acids in standard energy buffer (SB) with yeast extract. Baseline correction was performed by subtracting the group minimum value from each data point and removing background fluorescence from a negative control without template. Error bars (bar chart) and bands (time-series plot) represent the standard deviation for n=2 samples. YE: Yeast extract SB: standard Energy buffer. Top: Timeseries vizualisation of flourescence, standard deviation is depicted as an error band (n=2). Bottom: Mean value of the last timepoint 8.83hours.
  "

  width="50%"
  height="50%"
/>
  

Surprisingly, the replacement of amino acids with yeast extract resulted in three times as high of an activity than the canonical energy buffer (Figure 18). This is in disagreement with the findings of Nagappa et al. (2022) where the yeast extract variants performed less than the standard buffer \[10\].

Next, we aimed to assess if replacing the amino acid source had an effect on the energy dynamics in the cell extract. For this, we repeated the experiments outlined above with the replacement of nucleosides: NMPs instead of NTPs (Fig. 19).

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-19.png"
  alt=" Replacement of amino acids"
  caption="Figure 19: Replacement of Amino Acids in standard energy buffer (SB) with Yeast extract  and Tryptone with NMPs.  Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples.  SB:standard energy buffer  Tryp: Tryptone  YE: Yeast Extract
  "
  width="50%"
  height="50%"
/>
  

The resulting fluorescence was found to be lower than the standard energy buffer, potentially indicating an energy limitation resulting from yeast extract amino acid supplementation. It may be hypothesized that the yeast extract and tryptone do not cover the amino acid demand fully, necessitating their synthesis using native enzymes. This reduces the energy phosphate pool by increasing the demand of NTPs. However, the differences were insignificant indicating that the replacement of NTPs and amino acids could be conducted simultaneously.

### Assessing Different Yeast Extract Concentrations and Suppliers

In our discussions, we raised a concern that complex amino acid sources such as yeast extract might exhibit major batch-to-batch variability \[11\]. It was therefore paramount to verify whether or not the alternative energy solution still shows activity independent of the supplier. For this two different Yeast extract suppliers were chosen: Carl Roth (product no. 2363.2) and Sigma Aldrich (product no. Y1625) and subsequently tested for activity. Additionally, we wanted to assess the effect of different yeast extract concentrations on the activity of the cell-free system.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-20.png"
  alt="different energy buffers"
  caption="Figure 20: Assessment of energy buffers utilizing  yeast extracts from different suppliers and in different concentrations \[0.4%, 0.8% and 1.6%\]. S1: Carl Roth (product no. 2363.2). S2: Sigma Aldrich product no. Y1625. Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples. SB: Standard energy buffer.
  "
  width="50%"
  height="50%"
/>

While the yeast extract from different suppliers showed slight differences it was found to be negligible. Furthermore, in alignment with the findings of Nagappa et al. (2022), the medium-range concentration of yeast extract showed the highest activity (Fig. 20) \[10\].

#### **Replacement of 3-PGA with Maltodextrin**

One of the most cost-prohibitive constituents of the canonical energy solution is 3-PGA (3-phosphoglyceric acid). Substituting this component could result in a reduction in price of 49.8 %.   

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-21.png"
  alt=" price reduction"
  caption="Figure 21: Price reduction achievable by the replacement of NTPs with NMPs
  "

  width="50%"
  height="50%"
/>

In previous work, 3-PGA was substituted with maltodextrin along with HMP as a phosphate source \[5\], \[12\], \[13\]. In alignment with the previous literature, we sought to assess the effects of maltodextrin substitution on the activity of the system.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/dein-abschnittstext.jpg"
  alt=" price reduction"
  caption="Figure 22: Pathway of Protein synthesis from Maltodextrin and HMP
  "

  width="50%"
  height="50%"
/>

  

Maltodextrin is broken down via phosphorylation using HMP as a phosphate donor, producing glucose-1-phosphate, which enters glycolysis to generate ATP. Coenzymes like NAD and CoA enhance ATP regeneration and inorganic phosphate (iP) recycling, while lactate and acetate are produced as waste (Fig. 22) \[13\]. To avoid phosphate buildup, which hampers protein synthesis, Swartz's team explored phosphate-free energy sources like glucose and pyruvate, improving ATP regeneration through glycolysis (source, Swartz's team). Pyruvate can generate ATP without phosphate accumulation, and glucose is a cost-effective alternative to phosphate-based compounds.


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-23.png"
  alt=" pathway protein synthesis"
  caption=" "

  width="50%"
  height="50%"
/>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-23b.png"
  alt="pathway protein synthesis"
  caption= "Figure 23: Substitution of PGA with maltodextrin and Hexa-meta Phosphate. Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples. MD=Maltodextrin. PGA= 3-Phosphoglyceric acid. HMP= hexametaphosphate. Top: Timeseries vizualisation of flourescence, standard deviation is depicted as an error band (n=2). Bottom: Mean value of the last timepoint 9.96hours.
  "
  width="50%"
  height="50%"
/>
  

The Maltodextrin-based energy solution was found to gradually generate energy in contrast to the canonical one. The kinetics of sfGFP production were slower and the reaction did not reach saturation within the time-frame we analyzed (Fig.23). After 10 h, the maltodextrin sample surpassed the fluorescence of the sample with standard buffer, potentially outperforming the canonical energy buffer in the long run. Similar observations were made in a repeat experiment (Fig. 24). 
<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-24a.png"
  alt=" pathway protein synthesis"
  caption=" "

  width="50%"
  height="50%"
/>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-24b.png"
  alt=" pathway protein synthesis"
  caption= "Figure 24: Repeat experiment of substitution of PGA with maltodextrin and HMP.  Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples. MD=Maltodextrin. PGA= 3-Phosphoglyceric acid. HMP= hexametaphosphate. Top: Timeseries vizualisation of flourescence, standard deviation is depicted as an error band (n=2). Bottom: Mean value of the last timepoint 14.95hours.
  "
  width="50%"
  height="50%"
/>
  

These results indicate that maltodextrin may be used as a potential replacement for 3-PGA, especially if speed of protein production is not a concern.

#### **Replacement of Coenzyme A with Calcium Pantothenate**

Another component of the energy buffer that we sought to replace was Coenzyme A (CoA). Through the replacement of Coenzyme A with its precursor in the native biosynthetic pathway, namely pantothenate, the costs of the energy buffer could be reduced by an additional 18 % (Fig. 26). 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/atp.jpg"
  alt=" pathway protein synthesis"
  caption="Figure 25: Graphical visualization of the metabolic pathway fo Coenzyme A (CoA) generation from pantothenate.
  "

  width="50%"
  height="50%"
/>

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-26.png"
  alt=" pathway protein synthesis"
  caption="Figure 26: Graphical visualization of the cost reduction achievable through the substitution of Coenzyme A with Calcium pantothenate.
  "

  width="50%"
  height="50%"
/>
  

As there was no previous literature outlining the substitution of CoA in cell-free systems, we initially decided to supplement calcium-D(+)-pantothenate (CAS Nr. 137-08-6) in equimolar quantities to CoA (0.24 mM). 

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-27.png"
  alt=" pathway protein synthesis"
  caption="Figure 27: Replacement of Coenzyme A with Calcium Pantothenate with different nucleotide sources. The fluorescence after 10 hrs with 5 mM  p70-GFP template is shown. CaP: Calcium Pantothenate. CoA: Coenzyme A. Baseline correction was performed by subtracting the group minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples.
  "

  width="50%"
  height="50%"
/>

  

 Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples.

Interestingly, the energy buffer with calcium pantothenate performed better when NTPs were added but showed slightly decreased activity when using NMPs (Fig. 27). This may be related to the higher demand for NTPs during the synthesis of CoA. Despite this, our initial results indicate that Calcium pantothenate may be used as a potential replacement for Coenzyme A.

After our initial experiments outlining individual targets that may be substituted, we sought to investigate what combination of replacements is feasible through a design of experiment approach coupled with the development of a model that can best describe the cost activity landscape. 

As outlined in our [modelling page](https://2024.igem.wiki/tum-straubing/model#3-confirmatory-runs), we employed a design of experiment approach to identify an optimized variant that reduces the costs by a factor of 90 %. The results of the energy buffer optimization are detailed there. 

## **Other Experiments to Improve Accessibility** 

### Resuspension of Desiccated Lysate with Different Water Sources

Following discussions with our core team member Mara Valverde Rascón, a former member of the Tec-Chihuahua iGEM Team (2016), she recalled that her lab had issues with access to nuclease-free water due to resource limitations. Through this, she provided us with a great idea. To address availability constraints, we evaluated the activity of desiccated lysates containing  *Gene 1*, rehydrated with various water sources. These included nuclease-free water, distilled water, tap water and even water from the Danube river in Straubing. 


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-28.png"
  alt=" pathway protein synthesis"
  caption="Figure 28: Rehydration of dessicated lysate (Gene 1) with different water sources. \+: fresh lysate. Dest: Distilled Water. NFW: Nuclease Free Water. Baseline correction was performed by subtracting the group minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=3 samples.
  "

  width="50%"
  height="50%"
/>
  

To our surprise, we found that even water from the Danube river showed reasonable activity upon rehydration, presenting the real possibility of our prototype being used in point of care applications such as the surveillance of water sources using biosensors (Fig. 28). 

### Using Small Tabletop Centrifuges as Ultracentrifuge Replacement
For the final step in lysate processing, we opted to use a standard tabletop centrifuge, operating at 20 xg for 90 minutes, instead of the more specialized ultracentrifuge typically employed in conventional protocols. This adjustment offers significant advantages in terms of accessibility, as it eliminates the need for expensive, high-maintenance equipment, making the process more feasible for laboratories that may not have access to ultracentrifuges. Furthermore, the use of a tabletop centrifuge requires less technical expertise, reduces operational costs, and broadens the potential for adoption across various research settings.

To evaluate the impact of this alternative method, we divided the biomass from the same batch into two equal portions. One half was processed using the traditional protocol involving an ultracentrifuge, ensuring consistency with established lysate production procedures. The remaining half was processed using the more accessible tabletop centrifuge method. By directly comparing the results of these two approaches, we aimed to assess whether the simpler, more widely available centrifugation technique could provide comparable results, thus offering a practical solution for labs with limited resources. This comparison allowed us to determine the feasibility of replacing the ultracentrifuge without compromising the quality of the lysate produced.


<PictureFrame 
  src="https://static.igem.wiki/teams/5286/results/image-29.png"
  alt=" pathway protein synthesis"
  caption="Figure 29: Rehydration of dessicated lysate (Gene 1) with different water sources. 
  "

  width="50%"
  height="50%"
/>
  
  
Baseline correction was performed by subtracting the group  minimum value from each data point and removing background fluorescence from a negative control without template. Error bars represent the standard deviation for n=2 samples. 

We found that despite the processing of lysate with a small table top centrifuge the overall lysate activity was the same, potentially indicating a potential application for prototyping. 


## Conclusion and Future Experiments 

Within the framework of this project, we made accessibility of cell-free systems our main goal. Our team focused on developing innovative solutions to address the challenges that limit the widespread adoption of these powerful tools in synthetic biology. We recognized that the high costs associated with energy buffers, the need for specialized storage conditions, and reliance on expensive equipment were significant barriers for many labs and institutions.

To tackle these issues, we drew inspiration from nature, specifically the remarkable resilience of tardigrades. By incorporating tardigrade-derived intrinsically disordered proteins into our cell-free systems, we aimed to enhance their stability and reduce the need for costly equipment and storage methods. This approach not only improved the systems' performance but also made them more viable for use in underfunded labs and educational settings worldwide.  

We also explored cost-effective alternatives to traditional energy buffer components, identifying and replacing the most expensive ingredients. Our efforts in optimizing the energy buffer composition led to the development of more affordable formulations without compromising functionality. Additionally, we investigated low-cost vacuum desiccation methods and paper-based formats, further enhancing the portability and accessibility of cell-free systems.  

Throughout our project, we remained committed to creating solutions that would democratize access to cell-free technology. By addressing these challenges, we aimed to empower researchers and educators across various resource settings, ultimately advancing the field of synthetic biology and its applications.

We have already organized the shipment of our prototype to other iGEM teams, including Wageningen, Tec de Monterrey Guadalajara, and Mingdao Taiwan, among others. Additionally, following the advice of Dr. Aurore Dupin and Dr. Anibal Arce, we are focusing on further characterizing the lysate's functionality and addressing sources of variability. Specifically, we aim to quantify RNA protection using aptamers, which will also help us better assess the impact of Tardigrade proteins on protecting the transcriptional machinery. We will keep the community updated on these ongoing experiments as we approach the Grand Jamboree.

<details>
<summary>
## References
</summary>

[1\]	T. C. Boothby *u. a.*, „Tardigrades Use Intrinsically Disordered Proteins to Survive Desiccation“, *Mol. Cell*, Bd. 65, Nr. 6, S. 975-984.e5, März 2017, doi: 10.1016/j.molcel.2017.02.018.  

[2\]	Y. Yang *u. a.*, „Room-temperature Storage of Lyophilized Engineered Bacteria using Tardigrade Intrinsically Disordered Proteins“, 26\. Juni 2021\. doi: 10.1101/2021.06.25.449888.

[3\]	S. Tanaka *u. a.*, „Novel Mitochondria-Targeted Heat-Soluble Proteins Identified in the Anhydrobiotic Tardigrade Improve Osmotic Tolerance of Human Cells“, *PLOS ONE*, Bd. 10, Nr. 2, S. e0118272, Feb. 2015, doi: 10.1371/journal.pone.0118272.

[4\]	A. Didovyk, T. Tonooka, L. Tsimring, und J. Hasty, „Rapid and Scalable Preparation of Bacterial Lysates for Cell-Free Gene Expression“, *ACS Synth. Biol.*, Bd. 6, Nr. 12, S. 2198–2208, Dez. 2017, doi: 10.1021/acssynbio.7b00253.

[5\]	F. Guzman-Chavez *u. a.*, „Constructing Cell-Free Expression Systems for Low-Cost Access“, *ACS Synth. Biol.*, Bd. 11, Nr. 3, S. 1114–1128, März 2022, doi: 10.1021/acssynbio.1c00342.

[6\]	D. K. Karig, S. Bessling, P. Thielen, S. Zhang, und J. Wolfe, „Preservation of protein expression systems at elevated temperatures for portable therapeutic production“, *J. R. Soc. Interface*, Bd. 14, Nr. 129, S. 20161039, Apr. 2017, doi: 10.1098/rsif.2016.1039.

[7\]	C. Bower, C. Harbin, und D. Camenares, „GEM-Gate: A Low-Cost, Flexible Approach to BioBrick Assembly“, *DNA*, Bd. 3, Nr. 1, S. 33–40, Feb. 2023, doi: 10.3390/dna3010003.

[8\]	Z. Z. Sun, C. A. Hayes, J. Shin, F. Caschera, R. M. Murray, und V. Noireaux, „Protocols for Implementing an Escherichia coli Based TX-TL Cell-Free Expression System for Synthetic Biology“, *J. Vis. Exp.*, Nr. 79, S. 50762, Sep. 2013, doi: 10.3791/50762.

[9\]	M. C. Jewett, K. A. Calhoun, A. Voloshin, J. J. Wuu, und J. R. Swartz, „An integrated cell‐free metabolic platform for protein production and synthetic biology“, *Mol. Syst. Biol.*, Bd. 4, Nr. 1, S. 220, Jan. 2008, doi: 10.1038/msb.2008.57.

[10\]	L. K. Nagappa *u. a.*, „A ubiquitous amino acid source for prokaryotic and eukaryotic cell-free transcription-translation systems“, *Front. Bioeng. Biotechnol.*, Bd. 10, S. 992708, Sep. 2022, doi: 10.3389/fbioe.2022.992708. 

[11\]	S. Sparviero *u. a.*, „Yeast extracts from different manufacturers and supplementation of amino acids and micro elements reveal a remarkable impact on alginate production by A. vinelandii ATCC9046“, *Microb. Cell Factories*, Bd. 22, Nr. 1, S. 99, Mai 2023, doi: 10.1186/s12934-023-02112-3.

[12\]	Y. Wang und Y.-H. P. Zhang, „Cell-free protein synthesis energized by slowly-metabolized maltodextrin“, *BMC Biotechnol.*, Bd. 9, Nr. 1, S. 58, 2009, doi: 10.1186/1472-6750-9-58. 

[13\]	F. Caschera und V. Noireaux, „A cost-effective polyphosphate-based metabolism fuels an all E. coli cell-free expression system“, *Metab. Eng.*, Bd. 27, S. 29–37, Jan. 2015, doi: 10.1016/j.ymben.2014.10.007.
</details>

