# 🦺 Safety
import PictureFrame from '@site/src/components/PictureFrame';

<div style={{ 
    backgroundColor: "#E3EEFA", 
    color: "black", 
    padding: "20px", 
    borderRadius: "5px", 
    width: "100%", 
    boxSizing: "border-box", 
    margin: "20px 0", 
    border: "2px solid black", 
    textAlign: "center", 
    fontWeight: "bold", 
    display: "flex", 
    alignItems: "center", 
    justifyContent: "center", 
    height: "150px" /* Adjust height to control box size */ 
}}>
  Safety should be an integral component of synthetic biology. We believe that not only have we achieved working under safe conditions, but with our work, we can enable more teams and more groups of people to do the same by helping the broad adoption of cell-free systems into their workflows.
</div>

## Biosafety Considerations

Cell lysates have some special characteristics in terms of safety:

#### Reduced Risk of Contamination

Cell-based systems have the risk of “escaping” from the lab, which could impact human health and the environment. In contrast, this risk is reduced in cell-free systems \[4\] and almost eliminated if cell lysates and other solutions are filter sterilized. In our project, we sterilized our cell lysates with 0.2 micrometer filters and tested them for sterility. We also consulted with iGEM safety, trained professionals in the laws on genetic engineering in Germany (such as our PI, Henrike Niederholtmeyer), and a company in the field of cell-free synthetic biology (Invitris) to make sure we follow all relevant safety standards.

#### No Self-replication

Unlike cell-based systems, cell lysates cannot self-replicate. This eliminates the risk of uncontrolled growth or proliferation of engineered cells, which reduces the limitations on the applications of synthetic biology tools.


#### Controlled Environment for Reactions


Working with cell lysates allows for better control of the environment in which the biochemical reactions take place, which can further reduce the risk of complications arising from cellular metabolism and the likelihood of unintentional byproduct formation or interactions.

## This, in place, brings forth several advantages:


#### Simplified Handling

Since cell lysates don’t require the level of containment of living cells, they can be more easily transported and used in diverse settings. This allows applications in educational environments and in the field \[1\] \[2\].

#### Fewer Regulatory and Documentation Requirements

Cell-based systems often require extensive safety assessments and containment measures. The absence of living organisms can facilitate faster development and deployment of biotechnological applications \[3\] \[4\].

#### Risk Mitigation

Working with synthetic biology in a controlled environment, like our lab, is very different from working as a technician in the field or working as a professor in a classroom full of students giving a lesson. In the lab, surfaces and materials are routinely disinfected, and the contact of the lab’s contents with the outside is carefully handled. The release of genetically modified organisms and their products represents a significant risk to humans, food sources, and the environment, which is why their manipulation is relatively inaccessible.

According to the American National Institute of Health, a GMO escapee rate below 1 in 10<sup>8</sup> cells is considered to be acceptably safe \[6\]. We knew that using cell lysates already reduced the risk of GMO release, but we wanted to confirm it was failure-free.

Since a significant part of our vision involved bringing our lysate out of the lab and allowing other teams to use it, accidental release was a significant risk to address to ensure the safety of our product.

Our lysate is prepared by autolysis of *E. coli*, which leads to efficient lysis after freeze-thawing the cells. However, cell-to-cell differences in the production of the lysis protein R from phage lambda, which degrades the cell wall, could lead to a few surviving cells \[3\]. 

To evaluate the presence of bacteria in our lysates, we inoculated two LB plates with undiluted, unfiltered aliquots of 30 µl each. There was a single CFU in one of the plates (Fig. 1), which was initially promising, but after discussions with our advisors and the iGEM safety committee, it was clear that we needed to take a step further to sterilize our lysate.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/safety/safety-lysate-colony.png"
  alt="Description of the image"
  caption="Fig. 1. Sterility tests of unfiltered lysate. We plated 30µl of unfiltered lysate on two LB plates each. We detected one colony on one of the plates indicating that our lysate still contained a low concentration of live E. coli.
  
  "
  width="50%"
  height="50%"
/>


Filter sterilization had been initially suggested by our advisors, and it was confirmed as a viable strategy upon a review of the literature. After a visit to Invitris, a Startup from the 2018 iGEM runner-up project and one of our significant [**collaborators on Human Practices**](https://2024.igem.wiki/tum-straubing/human-practices), they provided us with industry-level sterility tests, based on rezarsurin reduction, which in the case of bacterial growth, turns bright pink and a standard growth media that is set to dilute to inoculate into plates to determine the most probable number (MPN) of colony forming units (CFUs) to confirm the sterility of the samples we would ship.

<PictureFrame 
  src="https://static.igem.wiki/teams/5286/safety/safety2.webp"
  alt="Sterility"
  caption="Fig. 2. Sterility tests of filtered lysate. 30 µl of filtered lysate were used to inoculate the tests. The transparency and the lack of red tinge in the tests after 24 hours of incubation at 36°C indicates sterility of the samples.
  
  "
  width="50%"
  height="50%"
/>


After speaking with the safety committee and professionals in the industry, we implemented filter sterilization with a 0.2 um filter, and a sterility test step on every batch of lysate we made that was intended for freeze drying and shipment.

After filter sterilization, we tested our lysate for sterility again. Plating assays produced no colonies (Fig. 1\) and also the rezarsurin tests demonstrated sterility (Fig. 2). Filtering did not affect the activity of our lysates in a negative way \[3\] \[5\].

## **Lab Safety**

The German Law for Regulation of Genetic Engineering (Gesetz zur Regelung der Gentechnik \[Gentechnikgesetz \- GenTG\]) stipulates the guidelines for Genetic Engineering work. The lab construction, safety training prior to lab work, definition of biosafety levels and measures are determined by this law \[7\]. Additionally, §14 GefStoffV and TRGS 555/GUV-I 850-0, regulate general work and safety measures in labs and work with chemicals.

Everyone who worked in the lab received a safety briefing as stated by law. Our briefing was directed by our PI, Henrike Niederholtmeyer, and the following points were provided:

- Lab access and rules, including appropriate clothing, eating, and eating rules  
- Responsible individuals, specifying emergency contacts and communication chains.  
- Biosafety equipment.  
- Disinfection and sterilization  
- Emergency procedures.  
- Physical biosecurity.  
- Chemical, fire and electrical safety.



<details>
<summary>
## References
</summary>
\[1\]     	A. Huang *et al.*, ‘BioBitsTM Explorer: A modular synthetic biology education kit’, *Sci. Adv.*, vol. 4, no. 8, p. eaat5105, Aug. 2018, doi: 10.1126/sciadv.aat5105.

\[2\]     	J. C. Stark *et al.*, ‘BioBitsTM Bright: A fluorescent synthetic biology education kit’, *Sci. Adv.*, vol. 4, no. 8, p. eaat5107, Aug. 2018, doi: 10.1126/sciadv.aat5107.

\[3\]     	A. Tinafar, K. Jaenes, and K. Pardee, ‘Synthetic Biology Goes Cell-Free’, *BMC Biol.*, vol. 17, no. 1, p. 64, Aug. 2019, doi: 10.1186/s12915-019-0685-x.

\[4\]     	J. W. Lee, C. T. Y. Chan, S. Slomovic, and J. J. Collins, ‘Next-generation biocontainment systems for engineered organisms’, *Nat. Chem. Biol.*, vol. 14, no. 6, pp. 530–537, Jun. 2018, doi: 10.1038/s41589-018-0056-x.

\[5\]     	Andriy Didovyk, Taishi Tonooka, Lev Tsimring, and Jeff Hasty, ‘Rapid and Scalable Preparation of Bacterial Lysates for Cell-Free Gene Expression | ACS Synthetic Biology’, vol. 6, no. 12, 2017, doi: https://doi.org/10.1021/acssynbio.7b00253.

\[6\]     	D. J. Wilson, ‘NIH guidelines for research involving recombinant DNA molecules’, *Account. Res.*, vol. 3, no. 2–3, pp. 177–185, Dec. 1993, doi: 10.1080/08989629308573848.

\[7\]	https://www.gesetze-im-internet.de/gentg/BJNR110800990.html. 
</details>

