# 📈 Scale Up

Previous small-scale experiments using <i>E. coli</i> BL21-Gold (DE3) engineered with a plasmid containing a bacteriophage lysis gene and a Tardigrade-derived stability-enhancing gene showed promising lysate activity. However, the flask setups resulted in lower titers, which required us to produce several batches, which had different activities. After our talks with Dr. Aníbal Arce and Dr. Fernando Guzmán, larger batches should enable us to achieve higher and more consistent yields, which are crucial for the characterization of our lysate and ensure reproducibility.

We used <i>E. coli</i> BL21-Gold (DE3) transformed with a plasmid encoding lysis <i>gene R</i> from bacteriophage lambda and Gene 1 <i>(CAHS107838)</i> for our upscaling experiments.

<!-- <hr/> -->

<div class="section">
 <details style={{width:"30%"}}>
    <summary> 
      <h3>Aim</h3>
      <h4>To scale up lysate production</h4>
    </summary>
  </details>
 <details style={{width:"30%"}}>
    <summary> 
      <h3>How</h3>
      <h4>By performing fermentation in a 2 L bioreactor and use the data to simulate industrial production</h4>
    </summary>
    <p></p>
  </details>
 <details style={{width:"30%"}}>
    <summary> 
      <h3>Outcomes</h3>
      <h4>Got 3 times yields compared to flask experimentation</h4>
    </summary>
    <p></p>
  </details>
</div>

<!-- <hr/> -->
<br/>
<div id="preliminary" class="section-column">
    <div>
        <h2> 
          Preliminary optimization prior to bioreactor runs:
        </h2>
    </div>
    
</div>
<!-- <hr/> -->
<div style={{ display: 'flex',gap:"20px", justifyContent: 'space-between' }}>
 <details style={{ width: '30%', flex: "1" }}>
    <summary> 
      <h3>Aim</h3>
      <h4>To investigate optimum inoculum volume to fit fermentation in 1 day before bioreactor runs.</h4>
    </summary>
    <p></p>
  </details>
 <details style={{ width: '30%', flex: "1" }}>
    <summary> 
      <h3>How</h3>
      <h4>By inoculating three 100 ml YTPG medium with 3 different inoculum volumes and find which is more suitable</h4>
    </summary>
  </details>
 <details style={{ width: '30%', flex: "1" }}>
    <summary> 
      <h3>Outcomes</h3>
      <h4>2% inoculum volume was suitable for 1 day experimentation.</h4>
    </summary>
    <p></p>
  </details>
</div>

<div>
  <img src="https://static.igem.wiki/teams/5286/scalingup/fig2.jpeg" alt="Experimental setup for optimum inoculum volume investigation" width="1000" height="300"/>
  <p style={{color:"black", textAlign:"center"}}><b>Fig. 1. Experimental setup for optimum inoculum volume investigation</b></p>
</div>
<!-- <hr/> -->

<details style={{ width: '100%', flex: "1" }}>
    <summary> 
      <h3>Detailed Experimental setup</h3>
    </summary>
    <div>
        <ol>
          <li>5 mL of 2xYTP overnight culture was prepared and inoculated from glycerol stock.</li>
          <li>Three 100 mL 2xYTPG media were prepared in 250 mL Erlenmeyer flasks.</li>
          <li>The media were inoculated with three different inoculum volumes: 0.25%, 0.5%, and 2%.</li>
          <li>OD<sub>600</sub> was measured over 7 hours using Ultospec 10 photometer.</li>
          <li>The shaker was set at 220 rpm and 37°C for both overnight and production media.</li>
        </ol>
    </div>
  </details>

<div class="section-column">
    <div>
        <h2> 
          Results:
        </h2>
    </div>
    <div>
        <p>
          Due to the limited availability of bioreactors, 2% inoculum volume was found to be more suitable to fulfill the bioreactor fermentation within 1 day, as shown in Fig. 3. 2% showed faster growth rate which could reflect its role in establishing the initial microbial load and the length of the lag phase and influences cell morphology and growth patterns [1].
          </p>
    </div>
</div>

<div class="section-column">
    <div style={{textAlign:"center"}}>
        <img src="https://static.igem.wiki/teams/5286/scalingup/graph.jpeg" alt="The effect of varying inoculum volume on growth tested in 100 ml 2xYTPG media in shake flasks" width="900" height="750"/>
        <p style={{color:"black", textAlign:"center"}}><b>Fig. 2. The effect of varying inoculum volume on growth tested in 100 ml 2xYTPG media in shake flasks</b></p>
    </div>
</div>

<hr/>

<div id="Bioreactors" class="section-column">
    <div>
        <h2>Using Bioreactors</h2>
        <h4>Aim of the experiment:</h4>
    </div>
    <div>
        <p>
          By using shaking flasks, we could only produce up to 15 g/L of biomass, which reflects the poor aeration and mixing conditions in flasks. We wanted to maximize the lysate production efficiency by using bioreactors as a first step in the way of industrial production.
        </p>
    </div>
</div>

<!-- <hr/> -->

<div class="section-column">
<details>
        <summary> 
          <b style={{fontSize: "18px", color:"#0065bd"}}>General Bioreactor Handling</b>
        </summary>
    <div>
        <p>
          2 HABITAT ferment dw 2 double-wall 2 L bioreactors were provided by Prof. Dr.-Ing. Michael Zavrel, Professur Bioverfahrenstechnik (BVT) on TUM Campus Straubing. Due to limited availability of bioreactors, the experimental plan was organized to be fulfilled within 3 days of lab work.
        </p>
        <br/>
    </div>
    <details>
        <summary> 
          <b style={{fontSize: "18px"}}>1- Bioreactor Assembly</b>
        </summary>
        <ol style={{listStyleType: "decimal"}}>
            <h4><b>The following instructions were based on the fermentation bible provided by BVT-TUM Campus Straubing.</b></h4>
            <li>The stirrer drive shaft was inserted.</li>
            <li>The stirrer was installed.</li>
            <li>The sampling tube was installed.</li>
            <li>The ring saver and flow breaker were mounted.</li>
            <li>The heat exchanger was attached.</li>
            <li>The bioreactor vessel was installed.</li>
            <li>The bioreactor was filled with medium.</li>
            <li>The lid was installed.</li>
            <li>The pH probe was installed.</li>
            <li>The pH probe was calibrated.</li>
            <li>The calibrated pH probe was installed.</li>
            <li>The dissolved oxygen (DO) probe was installed.</li>
            <li>The temperature and level sensor were installed.</li>
            <li>Dummy plugs were placed in the three "Reserve" connections and at the "Cooling finger" connection.</li>
            <li>The septum with a blind plug was mounted on the "Inoculation" recess with its counterpart.</li>
            <li>The double jacket was filled with distilled water.</li>
            <li>All sampling openings were sealed with aluminum foil.</li>
            <div style={{textAlign:"center"}}>
              <img src="https://static.igem.wiki/teams/5286/scalingup/fig4.jpeg" alt="The steps of bioreactor assembly." width="900" height="750"/>
              <p style={{color:"black", textAlign:"center"}}><b>Fig. 3. The steps of bioreactor assembly</b></p>
            </div>
        </ol>
    </details>
    <details>
        <summary> 
          <b style={{fontSize: "18px"}}>2- Bioreactor Autoclaving</b>
        </summary>
        <ol style={{listStyleType: "decimal"}}>
          <li>The bioreactor was autoclaved at 121°C for 15 minutes.</li>
          <li>The double jacket was connected to the thermostat using hoses, and the bioreactor was cooled to room temperature.</li>
          <li>The motor was connected.</li>
          <li>The foam sensor was mounted.</li>
          <li>The Peltier cooler was installed.</li>
          <li>The pump head and hoses were adjusted.</li>
          <li>Auxiliary systems for acid, base, and antifoam were connected.</li>
          <li>The exhaust gas outlet was connected, and pO2 was calibrated.</li>
          <li>The sterile filter was connected to the BlueVary for off-gas analysis.</li>
          <li>The heating jacket was mounted around the exhaust air filter.</li>
        </ol>
    </details>
    <details>
        <summary> 
          <b style={{fontSize: "18px"}}>3- Bioreactor inoculation</b>
        </summary>
        <ol style={{listStyleType: "decimal"}}>
          <li>Sterile syringes were used to aseptically inject 500 µL of Kanamycin and Ampicillin through the bioreactor septum.</li>
          <li>A sterile syringe was filled with 20 mL of overnight culture.</li>
          <li>The syringe was inserted through the septum, and the culture was injected into the bioreactor.</li>
          <li>The syringe was removed, the septum was ensured to be sealed, and the bioreactor process was started.</li>
        </ol>
    </details>
</details>
</div>

<!-- <hr/> -->
<br/>
<h2 style={{textAlign: "center"}}>Bioreactor Runs</h2>
<div class="section">
  <details style={{ width: '49%' }} open>
    <summary> 
      <h3>A. 2xYTPG Meduim</h3>
    </summary>
    <details open>
        <summary> 
          <h3>Aim</h3>
        </summary>
        <p>To scale up the production of lysate from the shake flask to 2L-bioreactors using 2xYTPG medium</p>
    </details>
    <details open>
        <summary> 
          <h3>How</h3>
        </summary>
        <p>By inoculating a 2L-bioreactor containing 2xYTPG medium for further details click <a href="#ytpg_meduim">here</a></p>
        <div style={{textAlign:"center"}}>
            <img src="https://static.igem.wiki/teams/5286/scalingup/fig5.jpeg" alt="Experimental plan for 2xYTPG medium in bioreactor" width="500" height="150"/>
            <p style={{color:"black", textAlign:"center"}}><b>Fig. 4. Experimental plan for 2xYTPG medium in bioreactor</b></p>
        </div>
    </details>
    <details open>
        <summary> 
          <h3>Outcome</h3>
        </summary>
        <p>Three-fold higher yields compared to shake flask experiments.</p>
    </details>
  </details>

  <details style={{ width: '49%' }} open>
    <summary> 
      <h3>B. High-Denisty Fed-Batch</h3>
    </summary>
    <details open>
        <summary> 
          <h3>Aim</h3>
        </summary>
        <p>To get higher biomass compared to 2xYTPG fermentation</p>
    </details>
    <details open>
        <summary> 
          <h3>How</h3>
        </summary>
        <p>By inoculating the same bioreactor containing defined medium with constant glycerol feed for further details click <a href="#HighDensityFedBatchProduction">here</a>.</p>
        <div style={{textAlign:"center"}}>
            <img src="https://static.igem.wiki/teams/5286/scalingup/fig6000.jpeg" alt="Experimental plan for YTPG medium in bioreactor" width="500" height="150"/>
            <p style={{color:"black", textAlign:"center"}}><b>Fig. 5. Experimental plan for YTPG medium in bioreactor</b></p>
        </div>
    </details>
    <details open>
        <summary> 
          <h3>Outcome</h3>
        </summary>
        <p>Failed run due to malfunction in pump and stirrer</p>
    </details>
  </details>
</div>

<!-- <hr/> -->

<div class="section-column" id="ytpg_meduim">
<div>
        <summary> 
          <b style={{fontSize: "18px", color:"#0065bd"}}>A. 2xYTPG Meduim:</b>
        </summary>
    <div>
    <div style={{textAlign:"center", width:"100%"}}>
      <img style={{borderRadius:"30px", objectFit:"cover"}} src="https://static.igem.wiki/teams/5286/scalingup/fig6.jpeg" alt="2xYTPG Medium prior to inoculation" width="500" height="450"/>
      <p style={{color:"black", textAlign:"center"}}><b>Fig. 6. 2xYTPG bioreactor run</b></p>
    </div>
    <div>
            <summary>
                <h3>Results</h3>
            </summary>
            <div>
            <div>
            <p>
                YTPG is a rich medium that supports robust bacterial growth by providing vital nutrients and growth factors [2]. As shown in Fig. 7, the stable and controlled conditions during this run allowed for consistent nutrient availability and optimal environmental parameters, resulting in a healthy and sustained growth phase.
            </p>
            <p>
                As illustrated in Fig. 7, the OD<sub>600</sub> value reached 4 within 6 hours post-inoculation. Harvesting at OD<sub>600</sub> values of 3.5 and 4 yielded biomass concentrations of 42.2 g/L and 44.25 g/L, respectively, which represent approximately three-fold higher yields compared to those achieved in shake flask experiments. This substantial increase likely reflects the enhanced environmental conditions and process control provided by bioreactor systems [3]. To further validate these results, additional bioreactor replicates are required; however, this was not feasible due to time constraints and limited bioreactor availability.
            </p>
            <p>
                Moreover, the lysate produced in bioreactors is expected to exhibit superior protein expression levels, potentially due to the lower cultivation temperature and improved aeration conditions [4]. Enhanced protein expression may contribute to the increased stability of the dried lysate as observed in shake flask studies we performed. This hypothesis should be confirmed through additional plate reader experiments to monitor GFP expression levels in both fresh and dried lysates from bioreactor runs, with comparisons to lysates produced under shake flask conditions.
            </p>
            </div>
            <div style={{textAlign:"center"}}>
              <img src="https://static.igem.wiki/teams/5286/scalingup/fig7.jpeg" alt=" Experimental plan for YTPG medium in bioreactor" width="1000" height="700"/>
              <p style={{color:"black", textAlign:"center"}}><b>Fig. 7. Growth of *E. coli* BL21-Gold (DE3)   with both plasmids in the bioreactor using 2xYTPG medium.</b></p>
            </div>
            </div>
        </div>
    </div>
    <br/>
    <details>
        <summary>
            <h3>Detailed protocol</h3>
        </summary>
            <ol style={{listStyleType: "decimal"}}>
              <li>5 mL of 2xYTP media was inoculated from glycerol stock in the morning.</li>
              <li>It was left on a shaker at 220 rpm and 37°C.</li>
              <li>1 mL of the morning culture was used to inoculate 100 mL 2xYTP at the end of the day to be used as the seed culture for bioreactor inoculation the next day.</li>
              <li>The next day, 20 mL of the 100 mL overnight culture was aseptically added to the bioreactor after supplementation with antibiotics.</li>
              <li>pH was maintained at 7 by using 0.5 M sulfuric acid and 0.5 M sodium hydroxide.</li>
              <li>Foam was controlled using antifoam Struktol.</li>
              <li>A 2.5 M glucose solution equivalent to 18 g was prepared, filter sterilized and added in two parts at 30-minute intervals to the bioreactor after inoculation.</li>
              <li>OD<sub>600</sub> was measured every 30 minutes.</li>
              <li>Once OD<sub>600</sub> reached 0.8, 2 mL of filter-sterilized 1 M IPTG solution was injected into the bioreactor.</li>
              <li>Every 1 hour after IPTG induction, 50 mL was harvested and processed as usual to produce lysate.</li>
              <li>After the initial glucose was depleted, as indicated by a rise in dissolved oxygen, the bioreactor was supplemented with extra 2.5 M glucose solution equivalent to 10 g of glucose.</li>
            </ol>
        </details>
        
</div>
</div>

<!-- <hr/> -->

<div class="section-column" id="HighDensityFedBatchProduction">
<div>
        <summary> 
          <b style={{fontSize: "18px", color:"#0065bd"}}>B. High-Density Fed-Batch Production:</b>
        </summary>
    <div>
    <p>
      High-density fermentation was performed in a 2 L vessel using a defined medium adapted from (Lau et al., 2004). The medium composition included 0.4 g/L (NH<sub>4</sub>)<sub>2</sub>SO<sub>4</sub>, 4.16 g/L KH<sub>2</sub>PO<sub>4</sub>, and 11.95 g/L K<sub>2</sub>HPO<sub>4</sub>. Prior to inoculation, the medium was supplemented aseptically with 10 g of glucose, 1.875 g of yeast extract, 0.31 g of MgSO<sub>4</sub>, appropriate antibiotics, and 3 mL of trace metal solution as described below:
    </p>
    <details style={{width:"30%"}}>
    <summary>
      <h4 style={{textAlign:"center"}}>Trace metal buffer solution components</h4>     
    </summary>
              <div >
                | Component                               | Amount        |
                |-----------------------------------------|---------------|
                | **Trace solution composition**          | **100 mL**   |
                | NaCl                                    | 0.5 g        |
                | ZnSO<sub>4</sub>.7H<sub>2</sub>O      | 0.1 g        |
                | MnCl<sub>2</sub>.4H<sub>2</sub>O      | 0.4 g        |
                | FeCl<sub>3</sub>                       | 0.475 g      |
                | CuSO<sub>4</sub>.5H<sub>2</sub>O      | 0.04 g       |
                | H<sub>3</sub>BO<sub>3</sub>           | 0.058 g      |
                | NaMoO<sub>4</sub>.H<sub>2</sub>O      | 0.05 g       |
                | Concentrated H<sub>2</sub>SO<sub>4</sub>| 800 μL       |
              </div>
    </details>
        <div style={{textAlign:"center"}}>
                <img src="https://static.igem.wiki/teams/5286/scalingup/fig8.jpeg" alt="dummy image" width="1000" height="600"/>
                <p style={{color:"black", textAlign:"center"}}><b>Fig. 8. Experimental plan for high density fed-batch fermentation in bioreactor</b></p>
        </div>
    </div>
    <br/>
    <details>
        <summary>
            <h3>Detailed protocol</h3>
        </summary>
        <p>The experimental design was based on [6], with adjustments made to account for the aeration limitations of the bioreactors used. Fermentation was carried out in two phases: pre-induction (Stage 1) and post-IPTG induction for protein biosynthesis (Stage 2).</p>
            <ol style={{listStyleType: "decimal"}}>
              <li>During Stage 1, fermentation was conducted at 37°C with an initial agitation rate of 600 rpm and an aeration rate of 2 VVM.</li>
              <li>
                The pH was maintained at 7 through automated additions of concentrated NaOH and H<sub>2</sub>SO<sub>4</sub>, which were monitored by an internal pH probe.
              </li>
              <li>Dissolved oxygen was kept at 50% saturation using an agitation and aeration cascade (600 to 1000 rpm, then 2 to 2.5 VVM).</li>
              <li>Antifoam was automatically added as needed to control foaming.</li>
              <li>When the culture reached an OD<sub>600</sub> of 0.8,  Stage 2 was initiated by the addition of IPTG to induce expression, and the dissolved oxygen was lowered to 30 % using the same cascade control.</li>
              <li>
              After the initial glucose was depleted, as indicated by a rise in dissolved oxygen, a filter-sterilized glycerol feed solution (500 mL) containing 186.5 g of glycerol, 3.9 g/L of MgSO<sub>4</sub>, 6 g/L of (NH<sub>4</sub>)<sub>2</sub>SO<sub>4</sub>, 15 mL of trace metal solution, and the appropriate antibiotics was continuously fed at 14.5 mL/h using a separate peristaltic pump.
              </li>
              <li>OD<sub>600</sub> measurements were taken from 1 mL culture samples every 30 minutes.</li>
              <br/>
              <h3>Feed solution composition</h3>
              <div style={{width:"27%"}}>
                <div>
                | Component                               | Amount        |
                |-----------------------------------------|---------------|
                | Feed solution                           | **500 mL**   |
                | Glycerol                                | 186.5 g      |
                | MgSO<sub>4</sub>                       | 1.95 g       |
                | (NH<sub>4</sub>)<sub>2</sub>SO<sub>4</sub>| 3 g      |
                | Antibiotics                             | 1 mL         |
                | Trace metal solution                    | 15 mL         |
            </div>
        </div>
            </ol>
     </details>
    <div open>
        <summary>
            <h3>Results</h3>
        </summary>
          <div style={{textAlign:"center"}}>
            <img src="https://static.igem.wiki/teams/5286/scalingup/fig9.jpeg" style={{borderRadius: "30px"}} alt="Experimental plan for YTPG medium in bioreactor" width="500" height="500"/>
            <p style={{color:"black", textAlign:"center"}}><b>Fig. 9. The high density fed-batch fermentation in a bioreactor</b></p>
        </div>
        <div>
           <div>
            <p>
              It was expected to get much higher OD<sub>600</sub> compared to flasks and 2xYTPG bioreactor runs. Unfortunately, due to an error in the feeding pump, it added 270 mL of the glycerol feed after 4.5 hrs of inoculation. Glycerol, while a common carbon source for <em>E. coli</em>, can become toxic at high concentrations, leading to osmotic stress and metabolic imbalances that can inhibit bacterial growth or cause cell death [7]. This overfeeding likely resulted in a significant reduction in viable cell density, as observed in the growth curve shown in Fig. 10 [8].
            </p>
            <br/>
            <p>
              Directly after the failure, the CO<sub>2</sub> was decreased almost to zero, which could reflect the death of all cells. After 8 hrs of inoculation, another sample was taken to check the cells; the OD<sub>600</sub> was found to be 2, so a light microscope was used to check the viability of the cells. New generations emerged that could overcome the severe osmotic stress.
            </p>
            <br/>
            <p>
              Shortly after the last measurement, the stirrer shaft failed to continue working and only allowed chaotic stirring, which severely affected the oxygenation of the culture Fig. 10. Consistent agitation is crucial in bioreactor operations to ensure homogenous mixing of nutrients and oxygen throughout the culture medium [9]. The erratic stirring would have caused fluctuations in oxygen levels and nutrient distribution, further stressing the bacterial culture and contributing to the observed growth failure.
            </p>
            <br/>
            <p>
              It was decided to leave the bioreactor on overnight. After 20 hrs of inoculation, a new sample was taken, and the OD<sub>600</sub> was found to be 6. These findings, despite the failure of the experiment, might reflect a higher production of the protocol compared to the first bioreactor run. To confirm this, the run must be performed again after fixing the tower.
            </p>
            <br/>
            <div style={{textAlign:"center"}}>
                    <img src="https://static.igem.wiki/teams/5286/scalingup/fig10.jpeg" alt="fig10" width="1000" height="700"/>
                    <p style={{color:"black", textAlign:"center"}}><b>Fig. 10. Growth of *E. coli* BL21-Gold (DE3) with both plasmids in the bioreactor using defined medium. Blue x represents the uncontrolled glycerol feed. Red x represents the failure of the stirrer</b></p>
            </div>
        </div>
    </div>
</div>

</div>
</div>

<!-- <hr/> -->

<div>
  <h2>Future experiments:</h2>
  <p>
    Replicates for 2xYTPG bioreactor run should be performed to confirm the high biomass yield  we got. High density fed batch fermentation must be repeated with replicates because the trial run was not successful. We expect to see much higher biomass yields when using high density fermentation while having a much cheaper media since it doesn’t have any tryptone and uses less glucose. Finally, testing the activity of lysates produced from both fermentations should be done to confirm theories regarding having more stability by fermenting in bioreactors.
  </p>
</div>

<br/>
<br/>
<hr/>

<div id="Industrial">
  <h1>Industrial scale lysate production simulation</h1>
  <p>
    Based on results from 2xYTPG bioreactor run, data was used to establish a Process Flow Diagram (PFD) and the consecutive economic and environmental analysis using SuperPro Designer software. 
  </p>
  <div style={{display:"flex" ,justifyContent: 'space-between' }}>
    <details style={{ width: '45%' }}>
      <summary>
        <h3>Process Flow Diagram (PFD)</h3>
      </summary>
      <p>
        A process flow diagram (PFD) illustrates the connections between the various steps in a manufacturing process. It displays the primary equipment required, material flows, operational parameters, and process order.
      </p>
    </details>
    <details style={{ width: '45%' }}>
      <summary>
        <h3>SuperPro Designer software</h3>
      </summary>
      <p>
        SuperPro Designer software models and optimizes batch and continuous processes across various industries, integrating manufacturing and environmental operations for various industries, including biotech, pharmaceuticals, chemicals, and food processing.
      </p>
    </details>
  </div>
</div>

<!-- <hr/> -->

<div>
  <div style={{display:"flex" ,justifyContent: 'space-between', flexDirection:"column" }}>
  <div>
    <div class="section">
      <details style={{ width: '30%' }} open>
        <summary>
          <h3>Aim</h3>
        </summary>
        <p>
          Simulate industrial scale lysate production and determine the cost drivers for a scaled-up process
        </p>
      </details>
      <details style={{ width: '30%' }} open>
        <summary>
          <h3>How</h3>
        </summary>
        <p>
          Create a model using SuperPro Designer software to mimic industrial production level
        </p>
      </details>
      <details style={{ width: '30%' }} open>
        <summary>
          <h3>Outcome</h3>
        </summary>
        <p>
          Model showed a high profitable process
        </p>
      </details>
    </div>
    <div>
      <summary>
        <h3>Results</h3>
      </summary>
      <div>
        <p>
          From Fig. 11, the economic analysis of the process reveals a detailed breakdown of capital and operating costs, as well as an overview of expected revenues. The total capital investment for the project is $63,374,000, covering equipment purchase, installation, process piping, instrumentation, and auxiliary facilities. The plant has a Direct Fixed Capital Cost of $59,241,000, indicating substantial infrastructure expenditure. The operating costs are estimated at $24,641,000 per year.
        </p>
        <br/>
        <p>
          The equipment specification indicates significant investments in multiple fermentation and downstream processing units. For example, there are two freeze-thaw modules costing $1,750,000, two large fermenters priced at $1,708,000, and a spray dryer at $141,000. The disk-stack centrifuges and blending tanks also add to the processing capacity. Total equipment costs add up to $9,921,000. The associated installation, piping, and other expenses result in a total plant cost of $51,514,000, and with contractor fees and contingencies, the Direct Fixed Capital increases further.
        </p>
        <br/>
        <p>
          .
        </p>
        <br/>
        <div id="fig11" style={{textAlign:"center"}}>
            <div style={{textAlign:"center"}}>
                    <img  id="imfig11" src="https://static.igem.wiki/teams/5286/scalingup/fig11.jpeg" alt="fig11" width="1000" height="700"/>
                    <p style={{color:"black", textAlign:"center"}}><b>Fig. 11. A Process Flow Diagram (PFD) illustrating the steps of the process, and showing equipment required, material flows, and operational parameters</b></p>
            </div>
            <br/>
        </div>
        <p>
          The economic analysis of the process reveals a detailed breakdown of capital and operating costs, as well as an overview of expected revenues. The total capital investment for the project is $63,374,000, covering equipment purchase, installation, process piping, instrumentation, and auxiliary facilities. The plant has a Direct Fixed Capital Cost of $59,241,000, indicating substantial infrastructure expenditure. The operating costs are estimated at $24,641,000 per year.
        </p>
        <br/>
        <p>
          
        </p>
      </div>
    </div>
   </div>
  </div>
</div>
<br/>
<div id="Conclusion">
  <h3>Conclusion</h3>
  <p>
    These bioreactor runs highlighted important parameters like aeration, mixing, and nutrient availability that are difficult to control in smaller-scale systems, which gave important insights into optimizing lysate production. The results of the experiments demonstrated that moving to bioreactors greatly increased lysate yields and consistency, opening the door to larger-scale industrial applications. We will be able to increase overall efficiency, decrease variability, and simplify the process thanks to this understanding.
    <br/>
    Subsequent efforts will concentrate on enhancing the circumstances for high-density fermentations and verifying the lysate quality on a large scale. In order to evaluate the process's viability, consistency, and cost-effectiveness, verifying these findings in larger bioreactors is crucial for guaranteeing a smooth transition to full-scale production and following the industrial standards. These findings have shaped the direction of the project by providing a clear pathway to scale-up, emphasizing the importance of bioreactor usage in achieving commercially viable lysate production.
  </p>
</div>
<br/>
<div>
  <details id="References">
    <summary>
      <h3>References</h3>
    </summary>
      <ul style={{listStyleType: "none", padding: "0", margin: "0"}}>
          <li>[1]	S. Vinroot and A. P. Torzilli, “Interactive Effects of Inoculum Density, Agitation, and pH on Dimorphism in a Salt Marsh Isolate of Aureobasidium pullulans,” Mycologia, vol. 80, no. 3, p. 376, May 1988, doi: 10.2307/3807635.</li>
          <li>[2]	J. Sambrook and D. W. Russell, “Molecular Cloning: A Laboratory Manual. Third Edition,” United States: Cold Spring Harbor Laboratory Press., p. 4.35, 2001, Accessed: Oct. 01, 2024. [Online]. Available: https://books.google.com/books/about/Molecular_Cloning.html?id=Bosc5JVxNpkC</li>
          <li>[3]	R. A. Gamboa-Suasnavart et al., “Scale-up from shake flasks to bioreactor, based on power input and Streptomyces lividans morphology, for the production of recombinant APA (45/47 kDa protein) from Mycobacterium tuberculosis,” World J Microbiol Biotechnol, vol. 29, no. 8, pp. 1421–1429, Aug. 2013, doi: 10.1007/S11274-013-1305-5/FIGURES/5.</li>
          <li>[4]	P. Neubauer and J. Winter, “Expression and Fermentation Strategies for Recombinant Protein Production in Escherichia Coli,” Recombinant Protein Production with Prokaryotic and Eukaryotic Cells. A Comparative View on Host Physiology, pp. 195–258, 2001, doi: 10.1007/978-94-015-9749-4_17.</li>
          <li>[5]	J. Lau, C. Tran, P. Licari, and J. Galazzo, “Development of a high cell-density fed-batch bioprocess for the heterologous production of 6-deoxyerythronolide B in Escherichia coli,” J Biotechnol, vol. 110, no. 1, pp. 95–103, May 2004, doi: 10.1016/j.jbiotec.2004.02.001.</li>
          <li>[6]	R. A. Scheel et al., “Optimizing a Fed-Batch High-Density Fermentation Process for Medium Chain-Length Poly(3-Hydroxyalkanoates) in Escherichia coli,” Front Bioeng Biotechnol, vol. 9, p. 618259, Feb. 2021, doi: 10.3389/FBIOE.2021.618259/BIBTEX.</li>
          <li>[7]	C. A. Smith, “Physiology of the bacterial cell. A molecular approach. By F C Neidhardt, J L Ingraham and M Schaechter. pp 507. Sinauer associates, Sunderland, MA. 1990. $43.95 ISBN 0–87893–608–4,” Biochem Educ, vol. 20, no. 2, pp. 124–125, Apr. 1992, doi: 10.1016/0307-4412(92)90139-D.</li>
          <li>[8]	P. Malakar, V. K. Singh, R. Karmakar, and K. V. Venkatesh, “Effect on β-galactosidase synthesis and burden on growth of osmotic stress in Escherichia coli,” Springerplus, vol. 3, no. 1, pp. 1–10, Dec. 2014, doi: 10.1186/2193-1801-3-748/FIGURES/7.</li>
          <li>[9]	M. L. . Shuler and Fikret. Kargi, “Bioprocess engineering : basic concepts,” p. 553, 2002.</li>
          <li>[10]     Cube Biotech. “Cell-Free *E. coli* Lysate.” Cube Biotech, https://cube biotech.com/products/cell-free-lysates/cell-free-e.coli-lysate/21001.</li> 
      </ul>

  </details>
</div>
<br/>
<!-- <hr/> -->



<div style={{flex: "0 0 45%", position:"fixed", top:"10%", right:"5%",borderLeft: "2px solid #0065bd", padding: "10px"}}>
  <ul style={{listStyleType: "none", padding: "0", margin: "0"}}>
    <li>
        <a href="#preliminary" style={{color:"#0065bd",fontWeight:"bold"}}>Inoculum Optimization</a>
    </li>
    <li>
        <a href="#Bioreactors" style={{color:"#0065bd",fontWeight:"bold"}}>Bioreactors Runs</a>
    </li>
    <li>
        <a href="#Industrial" style={{color:"#0065bd",fontWeight:"bold"}}>Industrial Simulation</a>
    </li>
    <li>
        <a href="#Conclusion" style={{color:"#0065bd",fontWeight:"bold"}}>Conclusion</a>
    </li>
    <li>
        <a href="#References" style={{color:"#0065bd",fontWeight:"bold"}}>References</a>
    </li>
  </ul>
</div>

