import React, { useState, useEffect } from 'react';
import { useLocation } from '@docusaurus/router';

const ReadingProgress = () => {
  const [width, setWidth] = useState(0);
  const { pathname } = useLocation();

  useEffect(() => {
    const updateProgress = () => {
      const scrollTop = window.scrollY;
      const docHeight = document.documentElement.scrollHeight;
      const winHeight = window.innerHeight;
      const scrollPercent = scrollTop / (docHeight - winHeight);
      setWidth(scrollPercent * 100);
    };

    window.addEventListener('scroll', updateProgress);
    updateProgress();

    return () => window.removeEventListener('scroll', updateProgress);
  }, [pathname]);

  return (
    <div style={{
      position: 'fixed',
      top: 'var(--ifm-navbar-height)',
      left: 0,
      zIndex: 1, // Reduced z-index to place it behind dropdown menus
      width: '100%',
      height: '6px',
      backgroundColor: '#0065bd'
    }}>
      <div style={{
        height: '100%',
        backgroundColor: '#74B77C',
        width: `${width}%`,
        transition: 'width 0.05s ease-in-out',
        borderTopRightRadius: '3px',
        borderBottomRightRadius: '3px'
      }} />
    </div>
  );
};

export default ReadingProgress;
