import React, { useState } from 'react';
import styled from 'styled-components';

const CollageContainer = styled.div`
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  grid-auto-rows: 100px;
  gap: 8px;
  width: 100%;
  max-width: 1200px;
  margin: 0 auto;
`;

const PhotoTile = styled.div`
  position: relative;
  overflow: hidden;
  cursor: pointer;
  transition: transform 0.3s ease;
  grid-column: span ${props => props.width};
  grid-row: span ${props => props.height};

  &:hover {
    transform: scale(1.05);
  }

  img {
    width: 100%;
    height: 100%;
    object-fit: cover;
  }
`;

const ExpandedPhoto = styled.div`
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.8);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 1000;
`;

const ExpandedImage = styled.img`
  max-width: 90%;
  max-height: 90%;
  object-fit: contain;
`;

const PhotoCollage = ({ photos }) => {
  const [expandedPhoto, setExpandedPhoto] = useState(null);

  const handlePhotoClick = (photo) => {
    setExpandedPhoto(photo);
  };

  const handleCloseExpanded = () => {
    setExpandedPhoto(null);
  };

  // Predefined grid pattern
  const gridPattern = [
    { width: 2, height: 2 },
    { width: 1, height: 1 },
    { width: 1, height: 1 },
    { width: 2, height: 1 },
    { width: 2, height: 1 },
    { width: 1, height: 2 },
    { width: 1, height: 1 },
    { width: 2, height: 1 },
    { width: 1, height: 1 },
    { width: 1, height: 1 },
  ];

  return (
    <CollageContainer>
      {photos.map((photo, index) => {
        const { width, height } = gridPattern[index % gridPattern.length];
        return (
          <PhotoTile
            key={index}
            width={width}
            height={height}
            onClick={() => handlePhotoClick(photo)}
          >
            <img src={photo} alt={`Photo ${index + 1}`} />
          </PhotoTile>
        );
      })}
      {expandedPhoto && (
        <ExpandedPhoto onClick={handleCloseExpanded}>
          <ExpandedImage src={expandedPhoto} alt="Expanded photo" />
        </ExpandedPhoto>
      )}
    </CollageContainer>
  );
};

export default PhotoCollage;